@@ -3,10 +3,10 @@
 #
 # KIWI NG documentation build configuration file
 #
+from datetime import datetime
 import sys
 from os.path import abspath, dirname, join, normpath
 import shlex
-import sphinx_rtd_theme
 
 # If extensions (or modules to document with autodoc) are in another directory,
 # add these directories to sys.path here. If the directory is relative to the
@@ -31,7 +31,8 @@ extensions = [
     'sphinx.ext.todo',
     'sphinx.ext.ifconfig',
     'sphinx.ext.viewcode',
-    'sphinx.ext.autodoc'
+    'sphinx.ext.autodoc',
+    'sphinx_rtd_theme'
 ]
 
 docopt_ignore = [
@@ -60,7 +61,6 @@ def setup(app):
     app.add_config_value('prolog_replacements', {}, True)
     app.connect('source-read', prologReplace)
     app.connect("autodoc-process-docstring", remove_module_docstring)
-    app.add_css_file('css/custom.css')
 
 
 prolog_replacements = {
@@ -78,13 +78,13 @@ prolog_replacements = {
     '{exc_description_live}': 'x86/leap/test-image-live',
     '{exc_description_wsl}': 'x86/tumbleweed/test-image-wsl',
     '{exc_description_docker}': 'x86/leap/test-image-docker',
-    '{exc_os_version}': '15.3',
+    '{exc_os_version}': '15.5',
     '{exc_image_version}': '1.15.3',
-    '{exc_repo_leap}': 'obs://openSUSE:Leap:15.3/standard',
+    '{exc_repo_leap}': 'obs://openSUSE:Leap:15.5/standard',
     '{exc_repo_tumbleweed}': 'http://download.opensuse.org/tumbleweed/repo/oss',
     '{exc_kiwi_repo}':
-        'obs://Virtualization:Appliances:Builder/openSUSE_Leap_15.3',
-    '{schema_version}': '7.4',
+        'obs://Virtualization:Appliances:Builder/openSUSE_Leap_15.5',
+    '{schema_version}': '8.0',
     '{kiwi}': 'KIWI NG',
     '{kiwi-product}': 'KIWI Next Generation (KIWI NG)',
     '{kiwi-legacy}': 'KIWI Legacy'
@@ -131,15 +131,15 @@ default_role="py:obj"
 
 # General information about the project.
 project = 'KIWI NG'
-copyright = '2020, Marcus Schäfer'
 author = 'Marcus Schäfer'
+copyright = f'2020-{datetime.now().year}, {author}'
 
 # The version info for the project you're documenting, acts as replacement for
 # |version| and |release|, also used in various other places throughout the
 # built documents.
 #
 # The short X.Y version.
-version = '9.25.22'
+version = '10.0.19'
 # The full version, including alpha/beta/rc tags.
 release = version
 
@@ -195,10 +195,6 @@ html_sidebars = {
 
 html_theme = "sphinx_rtd_theme"
 
-html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]
-
-html_static_path = ['.static']
-
 html_theme_options = {
     'collapse_navigation': False,
     'display_version': False
