@@ -30,7 +30,7 @@ function get_disk_list {
     local list_items
     local max_disk
     local kiwi_oem_maxdisk
-    local blk_opts="-p -n -r -o NAME,SIZE,TYPE"
+    local blk_opts="-p -n -r --sort NAME -o NAME,SIZE,TYPE"
     local message
     local blk_opts_plus_label="${blk_opts},LABEL"
     local kiwi_install_disk_part
@@ -76,7 +76,7 @@ function get_disk_list {
             continue
         fi
         disk_size=$(echo "${disk_meta}" | cut -f2 -d:)
-        if [ ${max_disk} -gt 0 ]; then
+        if [ "${max_disk}" -gt 0 ]; then
             local disk_size_bytes
             disk_size_bytes=$(binsize_to_bytesize "${disk_size}") || \
                 disk_size_bytes=0
