@@ -78,6 +78,7 @@ function _setup_interactive_service {
         echo "Wants=systemd-vconsole-setup.service"
         echo "Conflicts=emergency.service emergency.target"
         echo "[Service]"
+        echo "EnvironmentFile=/dialog_profile"
         echo "Environment=HOME=/"
         echo "Environment=DRACUT_SYSTEMD=1"
         echo "Environment=NEWROOT=/sysroot"
@@ -151,6 +152,6 @@ function ask_and_shutdown {
     if ! run_dialog --yesno "\"${text_message}\"" 7 80; then
         die "${text_message}"
     else
-        reboot -f -p
+        systemctl halt
     fi
 }
