@@ -15,6 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with kiwi.  If not, see <http://www.gnu.org/licenses/>
 #
+from abc import ABC, abstractmethod
 import os
 import re
 import logging
@@ -34,7 +35,7 @@ from kiwi.exceptions import (
 log = logging.getLogger('kiwi')
 
 
-class BootLoaderConfigBase:
+class BootLoaderConfigBase(ABC):
     """
     **Base class for bootloader configuration**
 
@@ -46,6 +47,7 @@ class BootLoaderConfigBase:
         self.root_dir = root_dir
         self.boot_dir = boot_dir or root_dir
         self.xml_state = xml_state
+        self.bootloader = xml_state.get_build_type_bootloader_name()
         self.arch = Defaults.get_platform_name()
 
         self.volumes_mount = []
@@ -60,6 +62,9 @@ class BootLoaderConfigBase:
         self.root_filesystem_is_overlay = xml_state.build_type.get_overlayroot()
         self.post_init(custom_args)
 
+    def __enter__(self):
+        return self
+
     def post_init(self, custom_args):
         """
         Post initialization method
@@ -70,13 +75,13 @@ class BootLoaderConfigBase:
         """
         self.custom_args = custom_args
 
+    @abstractmethod
     def write(self):
         """
         Write config data to config file.
 
         Implementation in specialized bootloader class required
         """
-        raise NotImplementedError
 
     def write_meta_data(
         self, root_device=None, write_device=None, boot_options=''
@@ -92,8 +97,10 @@ class BootLoaderConfigBase:
         """
         pass
 
+    @abstractmethod
     def setup_disk_image_config(
-        self, boot_uuid, root_uuid, hypervisor, kernel, initrd, boot_options={}
+        self, boot_uuid=None, root_uuid=None, hypervisor=None,
+        kernel=None, initrd=None, boot_options={}
     ):
         """
         Create boot config file to boot from disk.
@@ -115,8 +122,8 @@ class BootLoaderConfigBase:
 
         Implementation in specialized bootloader class required
         """
-        raise NotImplementedError
 
+    @abstractmethod
     def setup_install_image_config(
         self, mbrid, hypervisor, kernel, initrd
     ):
@@ -130,8 +137,8 @@ class BootLoaderConfigBase:
 
         Implementation in specialized bootloader class required
         """
-        raise NotImplementedError
 
+    @abstractmethod
     def setup_live_image_config(
         self, mbrid, hypervisor, kernel, initrd
     ):
@@ -145,8 +152,8 @@ class BootLoaderConfigBase:
 
         Implementation in specialized bootloader class required
         """
-        raise NotImplementedError
 
+    @abstractmethod
     def setup_disk_boot_images(self, boot_uuid, lookup_path=None):
         """
         Create bootloader images for disk boot
@@ -160,8 +167,8 @@ class BootLoaderConfigBase:
 
         Implementation in specialized bootloader class required
         """
-        raise NotImplementedError
 
+    @abstractmethod
     def setup_install_boot_images(self, mbrid, lookup_path=None):
         """
         Create bootloader images for ISO boot an install media
@@ -171,8 +178,8 @@ class BootLoaderConfigBase:
 
         Implementation in specialized bootloader class required
         """
-        raise NotImplementedError
 
+    @abstractmethod
     def setup_live_boot_images(self, mbrid, lookup_path=None):
         """
         Create bootloader images for ISO boot a live ISO image
@@ -182,8 +189,8 @@ class BootLoaderConfigBase:
 
         Implementation in specialized bootloader class required
         """
-        raise NotImplementedError
 
+    @abstractmethod
     def setup_sysconfig_bootloader(self):
         """
         Create or update etc/sysconfig/bootloader by parameters
@@ -191,7 +198,6 @@ class BootLoaderConfigBase:
 
         Implementation in specialized bootloader class required
         """
-        raise NotImplementedError
 
     def create_efi_path(self, in_sub_dir='boot/efi'):
         """
@@ -349,10 +355,7 @@ class BootLoaderConfigBase:
             log.warning('Switching to standard install')
             boot_id = 1
 
-        if loader and loader == 'isolinux':
-            return menu_list[boot_id].name
-        else:
-            return menu_list[boot_id].menu_id
+        return menu_list[boot_id].menu_id
 
     def get_boot_path(self, target='disk'):
         """
@@ -380,10 +383,13 @@ class BootLoaderConfigBase:
             disk_setup = DiskSetup(self.xml_state, self.boot_dir)
             need_boot_partition = disk_setup.need_boot_partition()
             if need_boot_partition:
-                # if an extra boot partition is used we will find the
-                # data directly in the root of this partition and not
-                # below the boot/ directory
-                bootpath = '/'
+                if self.bootloader != 'zipl':
+                    # if an extra boot partition is used we will find the
+                    # data directly in the root of this partition and not
+                    # below the boot/ directory. An exception to this case
+                    # is the zipl bootloader which finds its target
+                    # according to the mount path.
+                    bootpath = '/'
 
         if target == 'disk':
             if not need_boot_partition:
@@ -495,8 +501,6 @@ class BootLoaderConfigBase:
 
         if target == 'grub2':
             return gfxmode_map[gfxmode].grub2
-        elif target == 'isolinux':
-            return gfxmode_map[gfxmode].isolinux
         else:
             return gfxmode
 
@@ -507,7 +511,7 @@ class BootLoaderConfigBase:
         self.root_mount = MountManager(
             device=root_device
         )
-        if 's390' in self.arch:
+        if 's390' in self.arch and self.bootloader == 'grub2_s390x_emu':
             self.boot_mount = MountManager(
                 device=boot_device,
                 mountpoint=self.root_mount.mountpoint + '/boot/zipl'
@@ -657,8 +661,7 @@ class BootLoaderConfigBase:
             'node': f'/dev/disk/{persistency_type}/{location}'
         }
 
-    def __del__(self):
-        log.info('Cleaning up %s instance', type(self).__name__)
+    def __exit__(self, exc_type, exc_value, traceback):
         for volume_mount in reversed(self.volumes_mount):
             volume_mount.umount()
         if self.device_mount:
