@@ -31,6 +31,7 @@ from kiwi.defaults import Defaults
 from kiwi.exceptions import KiwiFileNotFound
 from kiwi.firmware import FirmWare
 from kiwi.path import Path
+from kiwi.system.identifier import SystemIdentifier
 from kiwi.utils.sync import DataSync
 from kiwi.utils.sysconfig import SysConfig
 
@@ -121,9 +122,9 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         ]
 
         self.terminal_output = \
-            terminal_output if terminal_output in terminal_output_grub else ''
+            terminal_output if terminal_output in terminal_output_grub else 'gfxterm'
         self.terminal_input = \
-            terminal_input if terminal_input in terminal_input_grub else ''
+            terminal_input if terminal_input in terminal_input_grub else 'console'
 
         self.gfxmode = self.get_gfxmode('grub2')
         self.theme = self.get_boot_theme()
@@ -132,6 +133,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         self.timeout_style = \
             self.xml_state.get_build_type_bootloader_timeout_style()
         self.displayname = self.xml_state.xml_data.get_displayname()
+        self.bls = self.xml_state.get_build_type_bootloader_bls()
         self.serial_line_setup = \
             self.xml_state.get_build_type_bootloader_serial_line_setup()
         self.continue_on_timeout = self.get_continue_on_timeout()
@@ -174,13 +176,10 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 )
 
         if self.xml_state.is_xen_server():
-            self.hybrid_boot = False
             self.multiboot = True
         elif self.xen_guest:
-            self.hybrid_boot = False
             self.multiboot = False
         else:
-            self.hybrid_boot = True
             self.multiboot = False
 
         self.grub2 = BootLoaderTemplateGrub2()
@@ -207,6 +206,9 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             with open(config_file, 'w') as config:
                 config.write(self.config)
 
+    def setup_sysconfig_bootloader(self):
+        raise NotImplementedError
+
     def write_meta_data(
         self, root_device=None, write_device=None, boot_options=''
     ):
@@ -312,7 +314,6 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         # One fine day the following fix methods can hopefully
         # be deleted...
         if self.xml_state.build_type.get_overlayroot_write_partition() is not False:
-            self._fix_grub_to_support_dynamic_efi_and_bios_boot(config_file)
             self._fix_grub_root_device_reference(config_file, boot_options)
             self._fix_grub_loader_entries_boot_cmdline()
             self._fix_grub_loader_entries_linux_and_initrd_paths()
@@ -378,9 +379,8 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             )
         else:
             log.info('--> Using standard boot install template')
-            hybrid_boot = True
             template = self.grub2.get_install_template(
-                self.failsafe_boot, hybrid_boot, has_graphics, has_serial,
+                self.failsafe_boot, has_graphics, has_serial,
                 self.continue_on_timeout
             )
         try:
@@ -395,7 +395,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             )
 
     def setup_live_image_config(
-        self, mbrid, hypervisor='xen.gz', kernel='linux', initrd='initrd'
+        self, mbrid: SystemIdentifier, hypervisor='xen.gz', kernel='linux', initrd='initrd'
     ):
         """
         Create grub2 config file to boot a live media ISO image
@@ -450,10 +450,9 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             )
         else:
             log.info('--> Using standard boot template')
-            hybrid_boot = True
             template = self.grub2.get_iso_template(
-                self.failsafe_boot, hybrid_boot,
-                has_graphics, has_serial, self.mediacheck_boot
+                self.failsafe_boot, has_graphics, has_serial,
+                self.mediacheck_boot
             )
         try:
             self.config = template.substitute(parameters)
@@ -466,7 +465,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 self.boot_dir, self.early_boot_script_efi, 'iso'
             )
 
-    def setup_install_boot_images(self, mbrid, lookup_path=None):
+    def setup_install_boot_images(self, mbrid: SystemIdentifier, lookup_path: str = None) -> None:
         """
         Create/Provide grub2 boot images and metadata
 
@@ -517,7 +516,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             loopback_file
         )
 
-    def setup_live_boot_images(self, mbrid, lookup_path=None):
+    def setup_live_boot_images(self, mbrid: SystemIdentifier, lookup_path=None):
         """
         Create/Provide grub2 boot images and metadata
 
@@ -573,7 +572,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             grub_image = Defaults.get_signed_grub_loader(self.root_dir, target_type)
             if grub_image and grub_image.filename:
                 bash_command = [
-                    'strings', grub_image.filename, '|', 'grep', 'EFI\/'
+                    'strings', grub_image.filename, '|', 'grep', r'EFI\/'
                 ]
                 efi_boot_path = Command.run(
                     ['bash', '-c', ' '.join(bash_command)],
@@ -713,8 +712,6 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         * SUSE_REMOVE_LINUX_ROOT_PARAM
         * GRUB_BACKGROUND
         * GRUB_THEME
-        * GRUB_USE_LINUXEFI
-        * GRUB_USE_INITRDEFI
         * GRUB_SERIAL_COMMAND
         * GRUB_CMDLINE_LINUX
         * GRUB_CMDLINE_LINUX_DEFAULT
@@ -787,18 +784,6 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             )
             if os.path.exists(os.sep.join([self.root_dir, theme_background])):
                 grub_default_entries['GRUB_BACKGROUND'] = theme_background
-        if self.firmware.efi_mode():
-            # linuxefi/initrdefi only exist on x86, others always use efi
-            if self.arch == 'ix86' or self.arch == 'x86_64':
-                use_linuxefi_implemented = Command.run(
-                    [
-                        'grep', '-q', 'GRUB_USE_LINUXEFI',
-                        self._get_grub2_mkconfig_tool()
-                    ], raise_on_error=False
-                )
-                if use_linuxefi_implemented.returncode == 0:
-                    grub_default_entries['GRUB_USE_LINUXEFI'] = 'true'
-                    grub_default_entries['GRUB_USE_INITRDEFI'] = 'true'
         if self.xml_state.build_type.get_btrfs_root_is_snapshot():
             grub_default_entries['SUSE_BTRFS_SNAPSHOT_BOOTING'] = 'true'
         if self.custom_args.get('crypto_disk'):
@@ -810,7 +795,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 self._get_grub2_mkconfig_tool()
             ], raise_on_error=False
         )
-        if enable_blscfg_implemented.returncode == 0:
+        if self.bls and enable_blscfg_implemented.returncode == 0:
             grub_default_entries['GRUB_ENABLE_BLSCFG'] = 'true'
 
         if grub_default_entries:
@@ -956,7 +941,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 os.sep.join(
                     [
                         self._get_bios_modules_path(lookup_path),
-                        Defaults.get_isolinux_bios_grub_loader()
+                        Defaults.get_iso_grub_loader()
                     ]
                 )
             ]
@@ -1390,37 +1375,6 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             filename='shim-install', root_dir=self.boot_dir
         )
 
-    def _fix_grub_to_support_dynamic_efi_and_bios_boot(self, config_file):
-        if self.firmware.efi_mode() and self.arch in ['x86_64', 'ix86']:
-            # On systems that are configured to use EFI with grub2
-            # there is no support for dynamic EFI environment checking.
-            # In this condition we change the grub config to add this
-            # support as follows:
-            #
-            # * Apply on grub with EFI
-            #    1. Modify grub.cfg to set linux/initrd as variables
-            #    2. Prepend hybrid setup to select linux vs. linuxefi on demand
-            #
-            # Please note this is a one time modification done by kiwi
-            # Any subsequent call of the grub config tool will overwrite
-            # the setup and disables dynamic EFI environment checking
-            # at boot time
-            with open(config_file) as grub_config_file:
-                grub_config = grub_config_file.read()
-                grub_config = re.sub(
-                    r'([ \t]+)linux(efi|16)*([ \t]+)', r'\1$linux\3',
-                    grub_config
-                )
-                grub_config = re.sub(
-                    r'([ \t]+)initrd(efi|16)*([ \t]+)', r'\1$initrd\3',
-                    grub_config
-                )
-            with open(config_file, 'w') as grub_config_file:
-                grub_config_file.write(
-                    Template(self.grub2.header_hybrid).substitute()
-                )
-                grub_config_file.write(grub_config)
-
     def _fix_grub_root_device_reference(self, config_file, boot_options):
         if self.root_reference:
             # grub2-mkconfig has no idea how the correct root= setup is
