@@ -28,7 +28,7 @@ from kiwi.command import Command
 from kiwi.storage.device_provider import DeviceProvider
 from kiwi.boot.image.base import BootImageBase
 from kiwi.boot.image import BootImage
-from kiwi.bootloader.config import BootLoaderConfig
+from kiwi.bootloader.config import create_boot_loader_config
 from kiwi.filesystem.squashfs import FileSystemSquashFs
 from kiwi.filesystem.isofs import FileSystemIsoFs
 from kiwi.firmware import FirmWare
@@ -42,7 +42,6 @@ from kiwi.archive.tar import ArchiveTar
 from kiwi.system.setup import SystemSetup
 from kiwi.iso_tools.base import IsoToolsBase
 from kiwi.xml_state import XMLState
-from kiwi.iso_tools.iso import Iso
 
 
 from kiwi.exceptions import (
@@ -191,15 +190,15 @@ class InstallImageBuilder:
                 self.target_dir, '/', self.squashed_diskname, '.squashfs'
             ]
         )
-        squashed_image = FileSystemSquashFs(
+        with FileSystemSquashFs(
             device_provider=DeviceProvider(),
             root_dir=self.squashed_contents.name,
             custom_args={
                 'compression':
                     self.xml_state.build_type.get_squashfscompression()
             }
-        )
-        squashed_image.create_on_file(squashed_image_file)
+        ) as squashed_image:
+            squashed_image.create_on_file(squashed_image_file)
         Command.run(
             ['mv', squashed_image_file, self.media_dir.name]
         )
@@ -207,65 +206,46 @@ class InstallImageBuilder:
         log.info(
             'Setting up install image bootloader configuration'
         )
-        if self.firmware.efi_mode():
-            # setup bootloader config to boot the ISO via EFI
-            # This also embedds an MBR and the respective BIOS modules
-            # for compat boot. The complete bootloader setup will be
-            # based on grub
-            bootloader_config = BootLoaderConfig.new(
-                self.bootloader, self.xml_state, root_dir=self.root_dir,
-                boot_dir=self.media_dir.name, custom_args={
-                    'grub_directory_name':
-                        Defaults.get_grub_boot_directory_name(self.root_dir),
-                    'grub_load_command':
-                        'configfile'
-                }
-            )
+        with self._create_bootloader_instance() as bootloader_config:
             bootloader_config.setup_install_boot_images(
                 mbrid=self.mbrid,
                 lookup_path=self.boot_image_task.boot_root_directory
             )
-        else:
-            # setup bootloader config to boot the ISO via isolinux.
-            # This allows for booting on x86 platforms in BIOS mode
-            # only.
-            bootloader_config = BootLoaderConfig.new(
-                'isolinux', self.xml_state, root_dir=self.root_dir,
-                boot_dir=self.media_dir.name
+            IsoToolsBase.setup_media_loader_directory(
+                self.boot_image_task.boot_root_directory,
+                self.media_dir.name,
+                bootloader_config.get_boot_theme()
             )
-        IsoToolsBase.setup_media_loader_directory(
-            self.boot_image_task.boot_root_directory, self.media_dir.name,
-            bootloader_config.get_boot_theme()
-        )
-        if self.firmware.bios_mode():
-            Iso(self.media_dir.name).setup_isolinux_boot_path()
-        bootloader_config.write_meta_data()
-        bootloader_config.setup_install_image_config(
-            mbrid=self.mbrid
-        )
-        bootloader_config.write()
+            bootloader_config.write_meta_data()
+            bootloader_config.setup_install_image_config(
+                mbrid=self.mbrid
+            )
+            bootloader_config.write()
 
-        # create initrd for install image
-        log.info('Creating install image boot image')
-        self._create_iso_install_kernel_and_initrd()
+            # create initrd for install image
+            log.info('Creating install image boot image')
+            self._create_iso_install_kernel_and_initrd()
 
-        # the system image initrd is stored to allow kexec
-        self._copy_system_image_initrd_to_iso_image()
+            # the system image initrd is stored to allow kexec
+            self._copy_system_image_initrd_to_iso_image()
 
-        if self.firmware.efi_mode():
-            efi_loader = Temporary(
-                prefix='efi-loader.', path=self.target_dir
-            ).new_file()
-            bootloader_config._create_embedded_fat_efi_image(efi_loader.name)
-            self.custom_iso_args['meta_data']['efi_loader'] = efi_loader.name
+            if self.firmware.efi_mode():
+                efi_loader = Temporary(
+                    prefix='efi-loader.', path=self.target_dir
+                ).new_file()
+                bootloader_config._create_embedded_fat_efi_image(
+                    efi_loader.name
+                )
+                self.custom_iso_args['meta_data']['efi_loader'] = \
+                    efi_loader.name
 
         # create iso filesystem from media_dir
         log.info('Creating ISO filesystem')
-        iso_image = FileSystemIsoFs(
+        with FileSystemIsoFs(
             device_provider=DeviceProvider(), root_dir=self.media_dir.name,
             custom_args=self.custom_iso_args
-        )
-        iso_image.create_on_file(self.isoname)
+        ) as iso_image:
+            iso_image.create_on_file(self.isoname)
         self.boot_image_task.cleanup()
 
     def create_install_pxe_archive(self) -> None:
@@ -300,9 +280,9 @@ class InstallImageBuilder:
             source_filename=self.diskname,
             keep_source_on_compress=True
         )
-        compress.xz(self.xz_options)
+        xz_archive = compress.xz(self.xz_options)
         Command.run(
-            ['mv', compress.compressed_filename, pxe_image_filename]
+            ['mv', xz_archive, pxe_image_filename]
         )
 
         # the system image transfer is checked against a checksum
@@ -376,6 +356,16 @@ class InstallImageBuilder:
         archive.create(self.pxe_dir.name)
         self.boot_image_task.cleanup()
 
+    def _create_bootloader_instance(self):
+        return create_boot_loader_config(
+            name=self.bootloader, xml_state=self.xml_state,
+            root_dir=self.root_dir,
+            boot_dir=self.media_dir.name,
+            custom_args=Defaults.get_grub_custom_arguments(
+                self.root_dir
+            ) if self.bootloader.startswith('grub') else {}
+        )
+
     def _create_pxe_install_kernel_and_initrd(self) -> None:
         kernelname = 'pxeboot.{0}.kernel'.format(self.pxename)
         initrdname = 'pxeboot.{0}.initrd'.format(self.pxename)
