@@ -52,8 +52,6 @@ usage: kiwi-ng -h | --help
                [--config=<configfile>]
                [--kiwi-file=<kiwifile>]
            system <command> [<args>...]
-       kiwi-ng compat <legacy_args>...
-       kiwi-ng --compat <legacy_args>...
        kiwi-ng -v | --version
        kiwi-ng help
 
@@ -121,17 +119,15 @@ global options for services: image, system
 import logging
 import sys
 import os
-import pkg_resources
+from importlib.metadata import entry_points
 from docopt import docopt
 
 # project
 from kiwi.exceptions import (
     KiwiUnknownServiceName,
     KiwiCommandNotLoaded,
-    KiwiLoadCommandUndefined,
-    KiwiCompatError
+    KiwiLoadCommandUndefined
 )
-from kiwi.path import Path
 from kiwi.version import __version__
 from kiwi.help import Help
 from kiwi.defaults import Defaults
@@ -179,38 +175,11 @@ class Cli:
             return 'system'
         elif self.all_args.get('result') is True:
             return 'result'
-        elif self.all_args.get('--compat') is True:
-            return 'compat'
-        elif self.all_args.get('compat') is True:
-            return 'compat'
         else:
             raise KiwiUnknownServiceName(
                 'Unknown/Invalid Servicename'
             )
 
-    def invoke_kiwicompat(self, compat_args):
-        """
-        Execute kiwicompat with provided legacy KIWI command line arguments
-
-        Example:
-
-        .. code:: python
-
-            invoke_kiwicompat(
-                '--build', 'description', '--type', 'vmx',
-                '-d', 'destination'
-            )
-
-        :param list compat_args: legacy kiwi command arguments
-        """
-        kiwicompat = Path.which('kiwicompat', access_mode=os.X_OK)
-        try:
-            os.execvp(kiwicompat, ['kiwicompat'] + compat_args)
-        except Exception as e:
-            raise KiwiCompatError(
-                '%s: %s' % (type(e).__name__, format(e))
-            )
-
     def get_command(self):
         """
         Extract selected command name
@@ -283,19 +252,19 @@ class Cli:
 
         :rtype: object
         """
-        discovered_tasks = {
-            entry_point.name: entry_point.load()
-            for entry_point in pkg_resources.iter_entry_points('kiwi.tasks')
-        }
+        discovered_tasks = {}
+        if sys.version_info >= (3, 12):
+            for entry in list(entry_points()):  # pragma: no cover
+                if entry.group == 'kiwi.tasks':
+                    discovered_tasks[entry.name] = entry.load()
+        else:  # pragma: no cover
+            module_entries = dict.get(entry_points(), 'kiwi.tasks')
+            for entry in module_entries:
+                discovered_tasks[entry.name] = entry.load()
+
         service = self.get_servicename()
         command = self.get_command()
 
-        if service == 'compat':
-            compat_arguments = self.all_args['<legacy_args>']
-            if '--' in compat_arguments:
-                compat_arguments.remove('--')
-            return self.invoke_kiwicompat(compat_arguments)
-
         if not command:
             raise KiwiLoadCommandUndefined(
                 'No command specified for {0} service'.format(service)
