@@ -18,12 +18,15 @@
 import logging
 import os
 import glob
+import importlib
+from importlib.resources import as_file
+from importlib.util import find_spec
+from importlib.machinery import ModuleSpec
 from collections import namedtuple
 import platform
 import yaml
-from pkg_resources import resource_filename
 from typing import (
-    List, NamedTuple, Optional
+    List, NamedTuple, Optional, Dict
 )
 
 # project
@@ -82,6 +85,11 @@ EDIT_BOOT_INSTALL_SCRIPT = 'edit_boot_install.sh'
 IMAGE_METADATA_DIR = 'image'
 ROOT_VOLUME_NAME = 'LVRoot'
 SHARED_CACHE_DIR = '/var/cache/kiwi'
+MODULE_SPEC: Optional[ModuleSpec] = find_spec('kiwi')
+RUNTIME_CHECKER_METADATA = '{}/runtime_checker_metadata.yml'.format(
+    os.path.dirname(MODULE_SPEC.origin or 'unknown')
+) if MODULE_SPEC else 'unknown'
+
 TEMP_DIR = '/var/tmp'
 CUSTOM_RUNTIME_CONFIG_FILE = None
 PLATFORM_MACHINE = platform.machine()
@@ -264,6 +272,16 @@ class Defaults:
         """
         return '/var/tmp/kiwi/satsolver'
 
+    @staticmethod
+    def set_runtime_checker_metadata(filename):
+        """
+        Sets the runtime checker metadata filename
+
+        :param str filename: a file path name
+        """
+        global RUNTIME_CHECKER_METADATA
+        RUNTIME_CHECKER_METADATA = filename
+
     @staticmethod
     def set_shared_cache_location(location):
         """
@@ -389,6 +407,11 @@ class Defaults:
         ]
         return exclude_list
 
+    @staticmethod
+    def get_runtime_checker_metadata() -> Dict:
+        with open(RUNTIME_CHECKER_METADATA) as meta:
+            return yaml.safe_load(meta)
+
     @staticmethod
     def get_exclude_list_from_custom_exclude_files(root_dir: str) -> List:
         """
@@ -475,31 +498,31 @@ class Defaults:
 
             .. code:: python
 
-                {'kernel_hex_mode': video_type(grub2='mode', isolinux='mode')}
+                {'kernel_hex_mode': video_type(grub2='mode')}
 
         :rtype: dict
         """
         video_type = namedtuple(
-            'video_type', ['grub2', 'isolinux']
+            'video_type', ['grub2']
         )
         return {
-            '0x301': video_type(grub2='640x480', isolinux='640 480'),
-            '0x310': video_type(grub2='640x480', isolinux='640 480'),
-            '0x311': video_type(grub2='640x480', isolinux='640 480'),
-            '0x312': video_type(grub2='640x480', isolinux='640 480'),
-            '0x303': video_type(grub2='800x600', isolinux='800 600'),
-            '0x313': video_type(grub2='800x600', isolinux='800 600'),
-            '0x314': video_type(grub2='800x600', isolinux='800 600'),
-            '0x315': video_type(grub2='800x600', isolinux='800 600'),
-            '0x305': video_type(grub2='1024x768', isolinux='1024 768'),
-            '0x316': video_type(grub2='1024x768', isolinux='1024 768'),
-            '0x317': video_type(grub2='1024x768', isolinux='1024 768'),
-            '0x318': video_type(grub2='1024x768', isolinux='1024 768'),
-            '0x307': video_type(grub2='1280x1024', isolinux='1280 1024'),
-            '0x319': video_type(grub2='1280x1024', isolinux='1280 1024'),
-            '0x31a': video_type(grub2='1280x1024', isolinux='1280 1024'),
-            '0x31b': video_type(grub2='1280x1024', isolinux='1280 1024'),
-            'auto': video_type(grub2='auto', isolinux='800 600')
+            '0x301': video_type(grub2='640x480'),
+            '0x310': video_type(grub2='640x480'),
+            '0x311': video_type(grub2='640x480'),
+            '0x312': video_type(grub2='640x480'),
+            '0x303': video_type(grub2='800x600'),
+            '0x313': video_type(grub2='800x600'),
+            '0x314': video_type(grub2='800x600'),
+            '0x315': video_type(grub2='800x600'),
+            '0x305': video_type(grub2='1024x768'),
+            '0x316': video_type(grub2='1024x768'),
+            '0x317': video_type(grub2='1024x768'),
+            '0x318': video_type(grub2='1024x768'),
+            '0x307': video_type(grub2='1280x1024'),
+            '0x319': video_type(grub2='1280x1024'),
+            '0x31a': video_type(grub2='1280x1024'),
+            '0x31b': video_type(grub2='1280x1024'),
+            'auto': video_type(grub2='auto')
         }
 
     @staticmethod
@@ -570,6 +593,15 @@ class Defaults:
         """
         return 'grub2'
 
+    @staticmethod
+    def get_grub_custom_arguments(root_dir: str) -> Dict[str, str]:
+        return {
+            'grub_directory_name':
+                Defaults.get_grub_boot_directory_name(root_dir),
+            'grub_load_command':
+                'configfile'
+        }
+
     @staticmethod
     def get_grub_boot_directory_name(lookup_path):
         """
@@ -808,6 +840,7 @@ class Defaults:
         shim_file_patterns = [
             shim_pattern_type('/usr/lib/shim/shim*.efi.signed.latest', 'shimx64.efi'),
             shim_pattern_type('/usr/lib/shim/shim*.efi.signed', 'shimx64.efi'),
+            shim_pattern_type('/usr/lib/grub/*-efi-signed', 'shimx64.efi'),
             shim_pattern_type('/usr/share/efi/*/shim.efi', None),
             shim_pattern_type('/usr/lib64/efi/shim.efi', None),
             shim_pattern_type('/boot/efi/EFI/*/shim[a-z]*.efi', None),
@@ -937,50 +970,9 @@ class Defaults:
                 return bios_grub_core
 
     @staticmethod
-    def get_syslinux_modules():
+    def get_iso_grub_loader():
         """
-        Returns list of syslinux modules to include on ISO
-        images that boots via isolinux
-
-        :return: base file names
-
-        :rtype: list
-        """
-        return [
-            'isolinux.bin',
-            'ldlinux.c32',
-            'libcom32.c32',
-            'libutil.c32',
-            'gfxboot.c32',
-            'gfxboot.com',
-            'menu.c32',
-            'chain.c32',
-            'mboot.c32'
-        ]
-
-    @staticmethod
-    def get_syslinux_search_paths():
-        """
-        syslinux is packaged differently between distributions.
-        This method returns a list of directories to search for
-        syslinux data
-
-        :return: directory names
-
-        :rtype: list
-        """
-        return [
-            '/usr/share/syslinux',
-            '/usr/lib/syslinux/bios',
-            '/usr/lib/syslinux/modules/bios',
-            '/usr/lib/ISOLINUX'
-        ]
-
-    @staticmethod
-    def get_isolinux_bios_grub_loader():
-        """
-        Return name of eltorito grub image used as isolinux loader
-        in BIOS mode if isolinux.bin should not be used
+        Return name of eltorito grub image used as ISO loader
 
         :return: file base name
 
@@ -988,6 +980,17 @@ class Defaults:
         """
         return 'eltorito.img'
 
+    @staticmethod
+    def get_iso_grub_mbr():
+        """
+        Return name of hybrid MBR image used as ISO boot record
+
+        :return: file base name
+
+        :rtype: str
+        """
+        return 'boot_hybrid.img'
+
     @staticmethod
     def get_signed_grub_loader(
         root_path: str, target_type: str = 'disk'
@@ -1679,12 +1682,23 @@ class Defaults:
         """
         return Defaults.project_file('xsl/master.xsl')
 
+    @staticmethod
+    def get_schematron_module_name():
+        """
+        Provides module name for XML SchemaTron validations
+
+        :return: python module name
+
+        :rtype: str
+        """
+        return 'lxml.isoschematron'
+
     @staticmethod
     def project_file(filename):
         """
         Provides the python module base directory search path
 
-        The method uses the resource_filename method to identify
+        The method uses the importlib.resources.path method to identify
         files and directories from the application
 
         :param string filename: relative project file
@@ -1693,7 +1707,8 @@ class Defaults:
 
         :rtype: str
         """
-        return resource_filename('kiwi', filename)
+        with as_file(importlib.resources.files('kiwi')) as path:
+            return f'{path}/{filename}'
 
     @staticmethod
     def get_imported_root_image(root_dir):
@@ -1896,6 +1911,94 @@ class Defaults:
         elif package_manager == 'pacman':
             return 'pacman'
 
+    @staticmethod
+    def get_discoverable_partition_ids() -> Dict[str, str]:
+        """
+        Provides arch specific partition UUIDs as defined
+        by the UAPI group
+
+        :return: partition UUIDs
+
+        :rtype: dict
+        """
+        arch = Defaults.get_platform_name()
+        part_uuids_archs = {
+            'x86_64': {
+                'root':
+                    '4f68bce3e8cd4db196e7fbcaf984b709',
+                'usr':
+                    '8484680c952148c69c11b0720656f69e',
+                'usr-verity':
+                    '77ff5f63e7b64633acf41565b864c0e6'
+            },
+            'ix86': {
+                'root':
+                    '44479540f29741b29af7d131d5f0458a',
+                'usr':
+                    '75250d768cc6458ebd66bd47cc81a812',
+                'usr-verity':
+                    '8f461b0d14ee4e819aa9049b6fb97abd'
+            },
+            'aarch64': {
+                'root':
+                    'b921b0451df041c3af444c6f280d3fae',
+                'usr':
+                    'b0e01050ee5f4390949a9101b17104e9',
+                'usr-verity':
+                    '6e11a4e7fbca4dedb9e9e1a512bb664e'
+            },
+            'riscv64': {
+                'root':
+                    '72ec70a6cf7440e6bd494bda08e8f224',
+                'usr':
+                    'beaec34b8442439ba40b984381ed097d',
+                'usr-verity':
+                    '8f1056be9b0547c481d6be53128e5b54'
+            }
+        }
+        part_uuids_arch = part_uuids_archs.get(arch) or {}
+        return {
+            'root':
+                part_uuids_arch.get('root') or '',
+            'usr':
+                part_uuids_arch.get('usr') or '',
+            'usr-verity':
+                part_uuids_arch.get('usr-verity') or '',
+            'usr-secondary':
+                '75250d768cc6458ebd66bd47cc81a812',
+            'usr-secondary-verity':
+                '8f461b0d14ee4e819aa9049b6fb97abd',
+            'esp':
+                'c12a7328f81f11d2ba4b00a0c93ec93b',
+            'xbootldr':
+                'bc13c2ff59e64262a352b275fd6f7172',
+            'swap':
+                '0657fd6da4ab43c484e50933c84b4f4f',
+            'home':
+                '933ac7e12eb44f13b8440e14e2aef915',
+            'srv':
+                '3b8f842520e04f3b907f1a25a76f98e8',
+            'var':
+                '4d21b016b53445c2a9fb5c16e091fd2d',
+            'tmp':
+                '7ec6f5573bc54acab29316ef5df639d1',
+            'user-home':
+                '773f91ef66d449b5bd83d683bf40ad16',
+            'linux-generic':
+                '0fc63daf848347728e793d69d8477de4'
+        }
+
+    @staticmethod
+    def get_bls_loader_entries_dir() -> str:
+        """
+        Provide default loader entries directory for BLS loaders
+
+        :return: directory name
+
+        :rtype: str
+        """
+        return '/boot/loader/entries'
+
     def get(self, key):
         """
         Implements get method for profile elements
