@@ -175,13 +175,6 @@ class KiwiCompressionFormatUnknown(KiwiError):
     """
 
 
-class KiwiCompatError(KiwiError):
-    """
-    Exception raised if the given kiwi compatibility command line
-    could not be understood by the compat option parser.
-    """
-
-
 class KiwiConfigFileNotFound(KiwiError):
     """
     Exception raised if no kiwi XML description was found.
@@ -352,12 +345,6 @@ class KiwiPackagesDeletePhaseFailed(KiwiError):
     """
 
 
-class KiwiIsoLoaderError(KiwiError):
-    """
-    Exception raised if no isolinux loader file could be found.
-    """
-
-
 class KiwiIsoMetaDataError(KiwiError):
     """
     Exception raised if an inconsistency in the ISO header
@@ -451,6 +438,12 @@ class KiwiOCIArchiveToolError(KiwiError):
     """
 
 
+class KiwiOSReleaseImportError(KiwiError):
+    """
+    Exception raised if reading etc/os-release caused an issue
+    """
+
+
 class KiwiPackageManagerSetupError(KiwiError):
     """
     Exception raised if an attempt was made to create a package
@@ -854,3 +847,9 @@ class KiwiOffsetError(KiwiError):
     Exception raised if the offset for a seek operation does not
     match the expected data to write
     """
+
+
+class KiwiBootLoaderDiskPasswordError(KiwiError):
+    """
+    Exception raised if the disk password could not be set
+    """
