@@ -64,7 +64,7 @@ class IsoToolsBase:
         self, custom_args: Dict[str, str] = None
     ) -> None:
         """
-        Create a set of standard parameters for the main isolinux loader
+        Create a set of standard parameters for the main loader
 
         Implementation in specialized tool class
 
@@ -122,8 +122,8 @@ class IsoToolsBase:
         Path.wipe(loader_data)
         Path.create(loader_data)
         grub_image_file_names = [
-            Defaults.get_isolinux_bios_grub_loader(),
-            'boot_hybrid.img'
+            Defaults.get_iso_grub_loader(),
+            Defaults.get_iso_grub_mbr()
         ]
         loader_files = []
         for grub_image_file_name in grub_image_file_names:
@@ -134,16 +134,6 @@ class IsoToolsBase:
             if grub_file and os.path.exists(grub_file):
                 loader_files.append(grub_file)
 
-        for syslinux_file_name in Defaults.get_syslinux_modules():
-            for syslinux_dir in Defaults.get_syslinux_search_paths():
-                syslinux_file = os.path.normpath(
-                    os.sep.join(
-                        [lookup_path, syslinux_dir, syslinux_file_name]
-                    )
-                )
-                if os.path.exists(syslinux_file):
-                    loader_files.append(syslinux_file)
-
         log.debug('Copying loader files to {0}'.format(loader_data))
         for loader_file in loader_files:
             log.debug('--> Copying {0}'.format(loader_file))
