@@ -44,6 +44,9 @@ class RepositoryBase:
 
         self.post_init(custom_args or [])
 
+    def __enter__(self):
+        return self
+
     def post_init(self, custom_args: List = []) -> None:
         """
         Post initialization method
@@ -166,3 +169,14 @@ class RepositoryBase:
         Command.run(
             ['bash', '--norc', script_path, repo_file]
         )
+
+    def cleanup(self) -> None:
+        """
+        Cleanup method
+
+        Implementation in specialized repository class
+        """
+        pass  # pragma: no cover
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        pass  # pragma: no cover
