@@ -623,40 +623,6 @@ class RuntimeChecker:
                     )
                 )
 
-    def check_syslinux_installed_if_isolinux_is_used(self) -> None:
-        """
-        ISO images that are configured to use isolinux
-        requires the host to provide a set of syslinux
-        binaries.
-        """
-        message = dedent('''\n
-            Required syslinux module(s) not found
-
-            The ISO image build for this image setup uses isolinux
-            and therefore requires the syslinux modules to be
-            available on the build host. Please make sure your
-            build host has the syslinux package installed.
-        ''')
-        firmware = FirmWare(self.xml_state)
-        if Defaults.is_x86_arch(
-            Defaults.get_platform_name()
-        ) and not firmware.efi_mode():
-            image_builds_iso = False
-            build_type = self.xml_state.get_build_type_name()
-            if build_type == 'iso':
-                image_builds_iso = True
-            elif build_type == 'oem':
-                install_iso = self.xml_state.build_type.get_installiso()
-                install_stick = self.xml_state.build_type.get_installstick()
-                if install_iso or install_stick:
-                    image_builds_iso = True
-            if image_builds_iso:
-                syslinux_check_file = Path.which(
-                    'isohdpfx.bin', Defaults.get_syslinux_search_paths()
-                )
-                if not syslinux_check_file:
-                    raise KiwiRuntimeError(message)
-
     def check_dracut_module_versions_compatible_to_kiwi(
         self, root_dir: str
     ) -> None:
@@ -747,14 +713,15 @@ class RuntimeChecker:
         message = dedent('''\n
             Required dracut module package missing in package list
 
-            The package '{0}' is required to build an installation
-            image for the selected oem image type. Please add the
-            following in your <packages type="image"> section to
-            your system XML description:
+            One of the packages '{0}' is required
+            to build an installation image for the selected oem image type.
+            Depending on your distribution, add the following in the
+            <packages type="image"> section:
 
-            <package name="{0}"/>
+            <package name="ONE_FROM_ABOVE"/>
         ''')
-        required_dracut_package = 'dracut-kiwi-oem-dump'
+        meta = Defaults.get_runtime_checker_metadata()
+        required_dracut_packages = meta['package_names']['dracut_oem_dump']
         initrd_system = self.xml_state.get_initrd_system()
         build_type = self.xml_state.get_build_type_name()
         if build_type == 'oem' and initrd_system == 'dracut':
@@ -765,49 +732,13 @@ class RuntimeChecker:
                 package_names = \
                     self.xml_state.get_bootstrap_packages() + \
                     self.xml_state.get_system_packages()
-                if required_dracut_package not in package_names:
+                if not RuntimeChecker._package_in_list(
+                    package_names, required_dracut_packages
+                ):
                     raise KiwiRuntimeError(
-                        message.format(required_dracut_package)
+                        message.format(required_dracut_packages)
                     )
 
-    def check_architecture_supports_iso_firmware_setup(self) -> None:
-        """
-        For creating ISO images a different bootloader setup is
-        performed depending on the configured firmware. If the
-        firmware is set to bios, isolinux is used and that limits
-        the architecture to x86 only. In any other case the appliance
-        configured bootloader is used. This check examines if the
-        host architecture is supported with the configured firmware
-        on request of an ISO image.
-        """
-        message = dedent('''\n
-            Unsupported firmware setup: {0} on {1} architecture
-
-            The selected firmware limits the creation of images to
-            the x86 platform. For the detected build host architecture
-            and the request to build a live or install ISO media
-            the EFI firmware must be used:
-
-            <type ... firmware="efi"/>
-        ''')
-        arch = Defaults.get_platform_name()
-        build_type = self.xml_state.get_build_type_name()
-        firmware = self.xml_state.build_type.get_firmware() or \
-            Defaults.get_default_firmware(arch)
-        if firmware == 'bios' and not Defaults.is_x86_arch(arch):
-            iso_build_requested = False
-            if build_type == 'iso':
-                iso_build_requested = True
-            elif build_type == 'oem':
-                install_iso = self.xml_state.build_type.get_installiso()
-                install_stick = self.xml_state.build_type.get_installstick()
-                if install_iso or install_stick:
-                    iso_build_requested = True
-            if iso_build_requested:
-                raise KiwiRuntimeError(
-                    message.format(firmware, arch)
-                )
-
     def check_dracut_module_for_disk_oem_in_package_list(self) -> None:
         """
         OEM images if configured to use dracut as initrd system
@@ -819,14 +750,14 @@ class RuntimeChecker:
         message = dedent('''\n
             Required dracut module package missing in package list
 
-            The package '{0}' is required for the selected
-            oem image type. Please add the following in your
-            <packages type="image"> section to your system XML
-            description:
+            One of the packages '{0}' is required
+            for the selected oem image type. Depending on your distribution,
+            add the following in the <packages type="image"> section:
 
-            <package name="{0}"/>
+            <package name="ONE_FROM_ABOVE"/>
         ''')
-        required_dracut_package = 'dracut-kiwi-oem-repart'
+        meta = Defaults.get_runtime_checker_metadata()
+        required_dracut_packages = meta['package_names']['dracut_oem_repart']
         initrd_system = self.xml_state.get_initrd_system()
         disk_resize_requested = self.xml_state.get_oemconfig_oem_resize()
         build_type = self.xml_state.get_build_type_name()
@@ -835,9 +766,11 @@ class RuntimeChecker:
             package_names = \
                 self.xml_state.get_bootstrap_packages() + \
                 self.xml_state.get_system_packages()
-            if required_dracut_package not in package_names:
+            if not RuntimeChecker._package_in_list(
+                package_names, required_dracut_packages
+            ):
                 raise KiwiRuntimeError(
-                    message.format(required_dracut_package)
+                    message.format(required_dracut_packages)
                 )
 
     def check_dracut_module_for_live_iso_in_package_list(self) -> None:
@@ -851,23 +784,25 @@ class RuntimeChecker:
         message = dedent('''\n
             Required dracut module package missing in package list
 
-            The package '{0}' is required for the selected
-            live iso image type. Please add the following in your
-            <packages type="image"> section to your system XML
-            description:
+            One of the packages '{0}' is required
+            for the selected live iso image type. Depending on your distribution,
+            add the following in your <packages type="image"> section:
 
-            <package name="{0}"/>
+            <package name="ONE_FROM_ABOVE"/>
         ''')
-        required_dracut_package = 'dracut-kiwi-live'
+        meta = Defaults.get_runtime_checker_metadata()
+        required_dracut_packages = meta['package_names']['dracut_live']
         type_name = self.xml_state.get_build_type_name()
         type_flag = self.xml_state.build_type.get_flags()
         if type_name == 'iso' and type_flag != 'dmsquash':
             package_names = \
                 self.xml_state.get_bootstrap_packages() + \
                 self.xml_state.get_system_packages()
-            if required_dracut_package not in package_names:
+            if not RuntimeChecker._package_in_list(
+                package_names, required_dracut_packages
+            ):
                 raise KiwiRuntimeError(
-                    message.format(required_dracut_package)
+                    message.format(required_dracut_packages)
                 )
 
     def check_dracut_module_for_disk_overlay_in_package_list(self) -> None:
@@ -881,23 +816,26 @@ class RuntimeChecker:
         message = dedent('''\n
             Required dracut module package missing in package list
 
-            The package '{0}' is required for the selected
-            overlayroot activated image type. Please add the
-            following in your <packages type="image"> section to
-            your system XML description:
+            The package '{0}' is required
+            for the selected overlayroot activated image type.
+            Depending on your distribution, add the following in your
+            <packages type="image"> section:
 
-            <package name="{0}"/>
+            <package name="ONE_FROM_ABOVE"/>
         ''')
         initrd_system = self.xml_state.get_initrd_system()
-        required_dracut_package = 'dracut-kiwi-overlay'
+        meta = Defaults.get_runtime_checker_metadata()
+        required_dracut_packages = meta['package_names']['dracut_overlay']
         if initrd_system == 'dracut' and \
            self.xml_state.build_type.get_overlayroot():
             package_names = \
                 self.xml_state.get_bootstrap_packages() + \
                 self.xml_state.get_system_packages()
-            if required_dracut_package not in package_names:
+            if not RuntimeChecker._package_in_list(
+                package_names, required_dracut_packages
+            ):
                 raise KiwiRuntimeError(
-                    message.format(required_dracut_package)
+                    message.format(required_dracut_packages)
                 )
 
     def check_efi_mode_for_disk_overlay_correctly_setup(self) -> None:
@@ -1064,6 +1002,17 @@ class RuntimeChecker:
                 message.format(fat_image_mbsize)
             )
 
+    @staticmethod
+    def _package_in_list(
+        package_list: List[str], search_list: List[str]
+    ) -> str:
+        result = ''
+        for search in search_list:
+            if search in package_list:
+                result = search
+                break
+        return result
+
     @staticmethod
     def _get_dracut_module_version_from_pdb(
         package_manager: str, package_name: str, root_dir: str
