@@ -23,9 +23,7 @@ from kiwi.command import Command
 from kiwi.storage.device_provider import DeviceProvider
 from kiwi.utils.command_capabilities import CommandCapabilities
 
-from kiwi.exceptions import (
-    KiwiLoopSetupError
-)
+from kiwi.exceptions import KiwiLoopSetupError
 
 log = logging.getLogger('kiwi')
 
@@ -51,6 +49,9 @@ class LoopDevice(DeviceProvider):
         self.filesize_mbytes = filesize_mbytes
         self.blocksize_bytes = blocksize_bytes
 
+    def __enter__(self):
+        return self
+
     def get_device(self) -> str:
         """
         Device node name
@@ -98,12 +99,13 @@ class LoopDevice(DeviceProvider):
         )
         self.node_name = loop_call.output.rstrip(os.linesep)
 
-    def __del__(self):
+    def __exit__(self, exc_type, exc_value, traceback):
         if self.node_name:
-            log.info('Cleaning up %s instance', type(self).__name__)
             try:
                 Command.run(['losetup', '-d', self.node_name])
-            except Exception:
-                log.warning(
-                    'loop device %s still busy', self.node_name
+            except Exception as issue:
+                log.error(
+                    'loop cleanup on {0} failed with: {1}'.format(
+                        self.node_name, issue
+                    )
                 )
