@@ -87,9 +87,7 @@ class CliTask:
             'check_dracut_module_for_disk_overlay_in_package_list': [],
             'check_dracut_module_for_disk_oem_in_package_list': [],
             'check_dracut_module_for_oem_install_in_package_list': [],
-            'check_architecture_supports_iso_firmware_setup': [],
             'check_appx_naming_conventions_valid': [],
-            'check_syslinux_installed_if_isolinux_is_used': [],
             'check_image_type_unique': [],
             'check_include_references_unresolvable': [],
             'check_luksformat_options_valid': [],
