@@ -18,6 +18,7 @@
 """
 usage: kiwi-ng result bundle -h | --help
        kiwi-ng result bundle --target-dir=<directory> --id=<bundle_id> --bundle-dir=<directory>
+           [--bundle-format=<format>]
            [--zsync-source=<download_location>]
            [--package-as-rpm]
        kiwi-ng result bundle help
@@ -48,6 +49,11 @@ options:
         are placed to the same download location
     --package-as-rpm
         Take all result files and create an rpm package out of it
+    --bundle-format=<format>
+        specify the bundle format to create the bundle.
+        If provided this setting will overwrite an eventually
+        provided bundle_format attribute from the main
+        image description
 """
 from collections import OrderedDict
 from textwrap import dedent
@@ -59,7 +65,9 @@ import os
 # project
 from kiwi.tasks.base import CliTask
 from kiwi.help import Help
-from kiwi.system.result import Result
+from kiwi.system.result import (
+    Result, result_file_type
+)
 from kiwi.path import Path
 from kiwi.utils.compress import Compress
 from kiwi.utils.checksum import Checksum
@@ -111,6 +119,10 @@ class ResultBundleTask(CliTask):
         result = Result.load(
             result_directory + '/kiwi.result'
         )
+
+        if self.command_args['--bundle-format']:
+            result.add_bundle_format(self.command_args['--bundle-format'])
+
         image_version = result.xml_state.get_image_version()
         image_name = result.xml_state.xml_data.get_name()
         image_description = result.xml_state.get_description_section()
@@ -155,35 +167,24 @@ class ResultBundleTask(CliTask):
             bundle_file_format_name = bundle_file_format_name.replace(
                 '%p', format(tags.p)
             )
+            # Insert Version string
+            bundle_file_format_name = bundle_file_format_name.replace(
+                '%v', format(tags.v)
+            )
             # Insert Bundle ID
             bundle_file_format_name = bundle_file_format_name.replace(
                 '%I', self.command_args['--id']
             )
             del ordered_results['bundle_format']
 
+        # copy result files
+        origin_files = []
+        copied_files = []
         for result_file in list(ordered_results.values()):
             if result_file.use_for_bundle:
-                extension = result_file.filename.split('.').pop()
-                if bundle_file_format_name:
-                    bundle_file_basename = '.'.join(
-                        [bundle_file_format_name, extension]
-                    )
-                else:
-                    bundle_file_basename = os.path.basename(
-                        result_file.filename
-                    )
-                    # The bundle id is only taken into account for image results
-                    # which contains the image version appended in its file name
-                    part_name = list(bundle_file_basename.partition(image_name))
-                    bundle_file_basename = ''.join(
-                        [
-                            part_name[0], part_name[1],
-                            part_name[2].replace(
-                                image_version,
-                                image_version + '-' + self.command_args['--id']
-                            )
-                        ]
-                    )
+                bundle_file_basename = self._get_bundle_file_basename(
+                    result, result_file, bundle_file_format_name
+                )
                 log.info('Creating %s', bundle_file_basename)
                 bundle_file = ''.join(
                     [bundle_directory, '/', bundle_file_basename]
@@ -193,11 +194,47 @@ class ResultBundleTask(CliTask):
                         'cp', result_file.filename, bundle_file
                     ]
                 )
+                copied_files.append(bundle_file)
+                result_file_basename = os.path.basename(result_file.filename)
+                if result_file_basename != bundle_file_basename:
+                    symlink_orignal_name = f'{bundle_directory}/{result_file_basename}'
+                    if os.path.islink(symlink_orignal_name):
+                        os.unlink(symlink_orignal_name)
+                    os.symlink(bundle_file, symlink_orignal_name)
+                    origin_files.append(symlink_orignal_name)
+
+        # check and fix file references due to possible bundle_format renames
+        for origin_file in origin_files:
+            origin_file_basename = os.path.basename(origin_file)
+            bundle_file_basename = os.path.basename(os.readlink(origin_file))
+            log.info(f'Checking file references for {origin_file_basename}')
+            for result_file in copied_files:
+                if 'text' in Command.run(['file', result_file]).output:
+                    log.info(f'--> {result_file}')
+                    Command.run(
+                        [
+                            'sed', '-ie',
+                            f's/{origin_file_basename}/{bundle_file_basename}/g',
+                            result_file
+                        ]
+                    )
+                    os.unlink(f'{result_file}e')
+            os.unlink(origin_file)
+
+        # finalize result data, checksums, compressions
+        for result_file in list(ordered_results.values()):
+            if result_file.use_for_bundle:
+                bundle_file_basename = self._get_bundle_file_basename(
+                    result, result_file, bundle_file_format_name
+                )
+                log.info(f'Finalizing {bundle_file_basename}')
+                bundle_file = ''.join(
+                    [bundle_directory, '/', bundle_file_basename]
+                )
                 if result_file.compress:
-                    log.info('--> XZ compressing')
+                    log.info('--> Compressing')
                     compress = Compress(bundle_file)
-                    compress.xz(self.runtime_config.get_xz_options())
-                    bundle_file = compress.compressed_filename
+                    bundle_file = compress.xz(self.runtime_config.get_xz_options())
 
                 if self.command_args['--zsync-source'] and result_file.shasum:
                     # Files with a checksum are considered to be image files
@@ -233,6 +270,7 @@ class ResultBundleTask(CliTask):
                                 os.linesep
                             )
                         )
+
         if self.command_args['--package-as-rpm']:
             ResultBundleTask._build_rpm_package(
                 bundle_directory,
@@ -242,6 +280,35 @@ class ResultBundleTask(CliTask):
                 list(glob.iglob(f'{bundle_directory}/*'))
             )
 
+    def _get_bundle_file_basename(
+        self, result: Result, result_file: result_file_type,
+        bundle_file_format_name: str
+    ) -> str:
+        image_version = result.xml_state.get_image_version()
+        image_name = result.xml_state.xml_data.get_name()
+        extension = result_file.filename.split('.').pop()
+        if bundle_file_format_name:
+            bundle_file_basename = '.'.join(
+                [bundle_file_format_name, extension]
+            )
+        else:
+            bundle_file_basename = os.path.basename(
+                result_file.filename
+            )
+            # The bundle id is only taken into account for image results
+            # which contains the image version appended in its file name
+            part_name = list(bundle_file_basename.partition(image_name))
+            bundle_file_basename = ''.join(
+                [
+                    part_name[0], part_name[1],
+                    part_name[2].replace(
+                        image_version,
+                        image_version + '-' + self.command_args['--id']
+                    )
+                ]
+            )
+        return bundle_file_basename
+
     @staticmethod
     def _build_rpm_package(
         bundle_directory: str, image_name: str, image_version: str,
