@@ -219,91 +219,82 @@ class SystemBuildTask(CliTask):
         self.run_checks(self.checks_after_command_args)
 
         log.info('Preparing new root system')
-        system = SystemPrepare(
+        with SystemPrepare(
             self.xml_state,
             image_root,
             self.command_args['--allow-existing-root']
-        )
-        manager = system.setup_repositories(
-            self.command_args['--clear-cache'],
-            self.command_args[
-                '--signing-key'
-            ] + self.xml_state.get_repositories_signing_keys(),
-            self.global_args['--target-arch']
-        )
-        system.install_bootstrap(
-            manager, self.command_args['--add-bootstrap-package']
-        )
+        ) as system:
+            with system.setup_repositories(
+                self.command_args['--clear-cache'],
+                self.command_args[
+                    '--signing-key'
+                ] + self.xml_state.get_repositories_signing_keys(),
+                self.global_args['--target-arch']
+            ) as manager:
+                system.install_bootstrap(
+                    manager, self.command_args['--add-bootstrap-package']
+                )
 
-        setup = SystemSetup(
-            self.xml_state, image_root
-        )
-        setup.import_description()
+                setup = SystemSetup(
+                    self.xml_state, image_root
+                )
+                setup.import_description()
 
-        # call post_bootstrap.sh script if present
-        setup.call_post_bootstrap_script()
+                # call post_bootstrap.sh script if present
+                setup.call_post_bootstrap_script()
 
-        system.install_system(
-            manager
-        )
-        if self.command_args['--add-package']:
-            system.install_packages(
-                manager, self.command_args['--add-package']
-            )
-        if self.command_args['--delete-package']:
-            system.delete_packages(
-                manager, self.command_args['--delete-package']
-            )
+                system.install_system(
+                    manager
+                )
+                if self.command_args['--add-package']:
+                    system.install_packages(
+                        manager, self.command_args['--add-package']
+                    )
+                if self.command_args['--delete-package']:
+                    system.delete_packages(
+                        manager, self.command_args['--delete-package']
+                    )
 
-        profile = Profile(self.xml_state)
+                profile = Profile(self.xml_state)
 
-        defaults = Defaults()
-        defaults.to_profile(profile)
-        profile.create(
-            Defaults.get_profile_file(image_root)
-        )
+                defaults = Defaults()
+                defaults.to_profile(profile)
+                profile.create(
+                    Defaults.get_profile_file(image_root)
+                )
 
-        setup.import_overlay_files()
-        setup.import_image_identifier()
-        setup.setup_groups()
-        setup.setup_users()
-        setup.setup_keyboard_map()
-        setup.setup_locale()
-        setup.setup_plymouth_splash()
-        setup.setup_timezone()
-        setup.setup_permissions()
+                setup.import_overlay_files()
+                setup.import_image_identifier()
+                setup.setup_groups()
+                setup.setup_users()
+                setup.setup_keyboard_map()
+                setup.setup_locale()
+                setup.setup_plymouth_splash()
+                setup.setup_timezone()
+                setup.setup_permissions()
 
-        # make sure manager instance is cleaned up now
-        del manager
+                # setup permanent image repositories after cleanup
+                setup.import_repositories_marked_as_imageinclude()
 
-        # setup permanent image repositories after cleanup
-        setup.import_repositories_marked_as_imageinclude()
+                # call config.sh script if present
+                setup.call_config_script()
 
-        # call config.sh script if present
-        setup.call_config_script()
+                # if configured, assign SELinux labels
+                setup.setup_selinux_file_contexts()
 
-        # if configured, assign SELinux labels
-        setup.setup_selinux_file_contexts()
+                # handle uninstall package requests, gracefully uninstall
+                # with dependency cleanup
+                system.pinch_system(force=False)
 
-        # handle uninstall package requests, gracefully uninstall
-        # with dependency cleanup
-        system.pinch_system(force=False)
+                # handle delete package requests, forced uninstall without
+                # any dependency resolution
+                system.pinch_system(force=True)
 
-        # handle delete package requests, forced uninstall without
-        # any dependency resolution
-        system.pinch_system(force=True)
-
-        # delete any custom rpm macros created
-        system.clean_package_manager_leftovers()
-
-        # make sure system instance is cleaned up now
-        del system
+                # delete any custom rpm macros created
+                system.clean_package_manager_leftovers()
 
         setup.call_image_script()
 
-        # make sure setup instance is cleaned up now
-        del setup
-
         log.info('Creating system image')
         self.run_checks(
             {
