@@ -18,5 +18,5 @@
 """
 Global version information used in kiwi and the package
 """
-__version__ = '9.25.22'
-__githash__ = '6de387477af679225ec1bb4f39ab9506ff5bbbc8'
+__version__ = '10.0.19'
+__githash__ = '$Format:%H$'
