@@ -578,6 +578,25 @@ class XMLState:
                 result.append(archive.get_name().strip())
         return sorted(result)
 
+    def get_ignore_packages(self, section_type: str) -> List:
+        """
+        List of ignore package names from the packages sections matching
+        section_type and type=build_type
+
+        :return: package names
+
+        :rtype: list
+        """
+        result = []
+        image_packages_sections = self.get_packages_sections(
+            [section_type, self.get_build_type_name()]
+        )
+        for packages in image_packages_sections:
+            for package in packages.get_ignore():
+                if self.package_matches_host_architecture(package):
+                    result.append(package.get_name().strip())
+        return sorted(result)
+
     def get_system_ignore_packages(self) -> List:
         """
         List of ignore package names from the packages sections matching
@@ -587,15 +606,18 @@ class XMLState:
 
         :rtype: list
         """
-        result = []
-        image_packages_sections = self.get_packages_sections(
-            ['image', self.get_build_type_name()]
-        )
-        for packages in image_packages_sections:
-            for package in packages.get_ignore():
-                if self.package_matches_host_architecture(package):
-                    result.append(package.get_name().strip())
-        return sorted(result)
+        return self.get_ignore_packages('image')
+
+    def get_bootstrap_ignore_packages(self) -> List:
+        """
+        List of ignore package names from the packages sections matching
+        type="image" and type=build_type
+
+        :return: package names
+
+        :rtype: list
+        """
+        return self.get_ignore_packages('bootstrap')
 
     def get_bootstrap_package_name(self) -> str:
         """
@@ -976,6 +998,19 @@ class XMLState:
         return bootloader.get_name() if bootloader else \
             Defaults.get_default_bootloader()
 
+    def get_build_type_bootloader_bls(self) -> bool:
+        """
+        Return bootloader bls setting for selected build type
+
+        :return: True or False
+
+        :rtype: bool
+        """
+        bootloader = self.get_build_type_bootloader_section()
+        if bootloader:
+            return bootloader.get_bls()
+        return True
+
     def get_build_type_bootloader_console(self) -> List[str]:
         """
         Return bootloader console setting for selected build type
@@ -1446,6 +1481,9 @@ class XMLState:
         container_config.update(
             self._match_docker_volumes()
         )
+        container_config.update(
+            self._match_docker_stopsignal()
+        )
         container_config.update(
             self._match_docker_environment()
         )
@@ -2686,6 +2724,15 @@ class XMLState:
                     container_volumes['volumes'].append(volume.get_name())
         return container_volumes
 
+    def _match_docker_stopsignal(self) -> dict:
+        container_config_section = self.get_build_type_containerconfig_section()
+        container_stopsignal = {}
+        if container_config_section:
+            stopsignal_section = container_config_section.get_stopsignal()
+            if stopsignal_section:
+                container_stopsignal['stopsignal'] = stopsignal_section[0]
+        return container_stopsignal
+
     def _match_docker_environment(self):
         container_config_section = self.get_build_type_containerconfig_section()
         container_env = {}
