@@ -1,5 +1,5 @@
 import logging
-from mock import (
+from unittest.mock import (
     patch, call, Mock, MagicMock
 )
 from pytest import (
@@ -13,6 +13,38 @@ from kiwi.exceptions import KiwiBootLoaderTargetError
 from kiwi.bootloader.config.base import BootLoaderConfigBase
 
 
+class BootLoaderConfigTestImpl(BootLoaderConfigBase):
+    def setup_install_image_config(self, mbrid, hypervisor, kernel, initrd):
+        return super().setup_install_image_config(mbrid, hypervisor, kernel, initrd)
+
+    def setup_disk_image_config(
+            self, boot_uuid=None, root_uuid=None, hypervisor=None, kernel=None,
+            initrd=None, boot_options=...):
+        return super().setup_disk_image_config(
+            boot_uuid, root_uuid, hypervisor, kernel, initrd, boot_options
+        )
+
+    def write(self):
+        return super().write()
+
+    def setup_live_image_config(self, mbrid, hypervisor, kernel, initrd):
+        return super().setup_live_image_config(
+            mbrid, hypervisor, kernel, initrd
+        )
+
+    def setup_install_boot_images(self, mbrid, lookup_path=None):
+        return super().setup_install_boot_images(mbrid, lookup_path)
+
+    def setup_disk_boot_images(self, boot_uuid, lookup_path=None):
+        return super().setup_disk_boot_images(boot_uuid, lookup_path)
+
+    def setup_live_boot_images(self, mbrid, lookup_path=None):
+        return super().setup_live_boot_images(mbrid, lookup_path)
+
+    def setup_sysconfig_bootloader(self):
+        return super().setup_sysconfig_bootloader()
+
+
 class TestBootLoaderConfigBase:
     @fixture(autouse=True)
     def inject_fixtures(self, caplog):
@@ -26,52 +58,13 @@ class TestBootLoaderConfigBase:
         self.state = XMLState(
             description.load()
         )
-        self.bootloader = BootLoaderConfigBase(
+        self.bootloader = BootLoaderConfigTestImpl(
             self.state, 'root_dir'
         )
 
     def setup_method(self, cls):
         self.setup()
 
-    def test_write(self):
-        with raises(NotImplementedError):
-            self.bootloader.write()
-
-    def test_setup_disk_image_config(self):
-        with raises(NotImplementedError):
-            self.bootloader.setup_disk_image_config(
-                'boot_uuid', 'root_uuid', 'hypervisor',
-                'kernel', 'initrd', 'options'
-            )
-
-    def test_setup_install_image_config(self):
-        with raises(NotImplementedError):
-            self.bootloader.setup_install_image_config(
-                'mbrid', 'hypervisor', 'kernel', 'initrd'
-            )
-
-    def test_setup_live_image_config(self):
-        with raises(NotImplementedError):
-            self.bootloader.setup_live_image_config(
-                'mbrid', 'hypervisor', 'kernel', 'initrd'
-            )
-
-    def test_setup_disk_boot_images(self):
-        with raises(NotImplementedError):
-            self.bootloader.setup_disk_boot_images('uuid')
-
-    def test_setup_install_boot_images(self):
-        with raises(NotImplementedError):
-            self.bootloader.setup_install_boot_images('mbrid')
-
-    def test_setup_live_boot_images(self):
-        with raises(NotImplementedError):
-            self.bootloader.setup_live_boot_images('mbrid')
-
-    def test_setup_sysconfig_bootloader(self):
-        with raises(NotImplementedError):
-            self.bootloader.setup_sysconfig_bootloader()
-
     @patch('kiwi.path.Path.create')
     def test_create_efi_path(self, mock_path):
         self.bootloader.create_efi_path()
@@ -198,16 +191,10 @@ class TestBootLoaderConfigBase:
     def test_get_install_image_boot_default(self, mock_installboot):
         mock_installboot.return_value = None
         assert self.bootloader.get_install_image_boot_default() == '0'
-        assert self.bootloader.get_install_image_boot_default('isolinux') == \
-            'Boot_from_Hard_Disk'
         mock_installboot.return_value = 'failsafe-install'
         assert self.bootloader.get_install_image_boot_default() == '2'
-        assert self.bootloader.get_install_image_boot_default('isolinux') == \
-            'Failsafe_--_Install_Bob'
         mock_installboot.return_value = 'install'
         assert self.bootloader.get_install_image_boot_default() == '1'
-        assert self.bootloader.get_install_image_boot_default('isolinux') == \
-            'Install_Bob'
 
     @patch('kiwi.xml_parse.type_.get_installboot')
     @patch('kiwi.xml_parse.type_.get_installprovidefailsafe')
@@ -318,13 +305,11 @@ class TestBootLoaderConfigBase:
     @patch('kiwi.xml_parse.type_.get_vga')
     def test_get_gfxmode_default(self, mock_get_vga):
         mock_get_vga.return_value = None
-        assert self.bootloader.get_gfxmode('isolinux') == '800 600'
         assert self.bootloader.get_gfxmode('grub2') == 'auto'
 
     @patch('kiwi.xml_parse.type_.get_vga')
     def test_get_gfxmode(self, mock_get_vga):
         mock_get_vga.return_value = '0x318'
-        assert self.bootloader.get_gfxmode('isolinux') == '1024 768'
         assert self.bootloader.get_gfxmode('grub2') == '1024x768'
 
     @patch('kiwi.xml_parse.type_.get_vga')
@@ -353,6 +338,7 @@ class TestBootLoaderConfigBase:
             return mount_managers.pop()
 
         self.bootloader.arch = 's390x'
+        self.bootloader.bootloader = 'grub2_s390x_emu'
 
         mock_MountManager.side_effect = mount_managers_effect
         self.bootloader._mount_system(
@@ -390,38 +376,38 @@ class TestBootLoaderConfigBase:
             return mount_managers.pop()
 
         mock_MountManager.side_effect = mount_managers_effect
-        self.bootloader.root_filesystem_is_overlay = True
-        self.bootloader._mount_system(
-            'rootdev', 'bootdev', 'efidev', {
-                'boot/grub2': {
-                    'volume_options': 'subvol=@/boot/grub2',
-                    'volume_device': 'device'
-                }
-            }, root_volume_name='root'
-        )
-        assert mock_MountManager.call_args_list == [
-            call(device='rootdev'),
-            call(device='bootdev', mountpoint='root_mount_point/boot'),
-            call(device='efidev', mountpoint='root_mount_point/boot/efi'),
-            call(device='device', mountpoint='root_mount_point/boot/grub2'),
-            call(device='/tmp', mountpoint='root_mount_point/tmp'),
-            call(device='/dev', mountpoint='root_mount_point/dev'),
-            call(device='/proc', mountpoint='root_mount_point/proc'),
-            call(device='/sys', mountpoint='root_mount_point/sys')
-        ]
-        root_mount.mount.assert_called_once_with(
-            options=['subvol=root']
-        )
-        boot_mount.mount.assert_called_once_with()
-        efi_mount.mount.assert_called_once_with()
-        volume_mount.mount.assert_called_once_with(
-            options=['subvol=@/boot/grub2']
-        )
-        proc_mount.bind_mount.assert_called_once_with()
-        sys_mount.bind_mount.assert_called_once_with()
-        dev_mount.bind_mount.assert_called_once_with()
 
-        del self.bootloader
+        with BootLoaderConfigTestImpl(self.state, 'root_dir') as bootloader:
+            bootloader.root_filesystem_is_overlay = True
+            bootloader._mount_system(
+                'rootdev', 'bootdev', 'efidev', {
+                    'boot/grub2': {
+                        'volume_options': 'subvol=@/boot/grub2',
+                        'volume_device': 'device'
+                    }
+                }, root_volume_name='root'
+            )
+            assert mock_MountManager.call_args_list == [
+                call(device='rootdev'),
+                call(device='bootdev', mountpoint='root_mount_point/boot'),
+                call(device='efidev', mountpoint='root_mount_point/boot/efi'),
+                call(device='device', mountpoint='root_mount_point/boot/grub2'),
+                call(device='/tmp', mountpoint='root_mount_point/tmp'),
+                call(device='/dev', mountpoint='root_mount_point/dev'),
+                call(device='/proc', mountpoint='root_mount_point/proc'),
+                call(device='/sys', mountpoint='root_mount_point/sys')
+            ]
+            root_mount.mount.assert_called_once_with(
+                options=['subvol=root']
+            )
+            boot_mount.mount.assert_called_once_with()
+            efi_mount.mount.assert_called_once_with()
+            volume_mount.mount.assert_called_once_with(
+                options=['subvol=@/boot/grub2']
+            )
+            proc_mount.bind_mount.assert_called_once_with()
+            sys_mount.bind_mount.assert_called_once_with()
+            dev_mount.bind_mount.assert_called_once_with()
 
         volume_mount.umount.assert_called_once_with()
         tmp_mount.umount.assert_called_once_with()
