@@ -2,12 +2,13 @@ import io
 import os
 import logging
 from collections import namedtuple
-from mock import (
+from unittest.mock import (
     patch, call, MagicMock, Mock
 )
 from pytest import (
     raises, fixture
 )
+import pytest
 
 import kiwi
 
@@ -16,7 +17,6 @@ from kiwi.defaults import grub_loader_type
 from kiwi.xml_state import XMLState
 from kiwi.xml_description import XMLDescription
 from kiwi.bootloader.config.grub2 import BootLoaderConfigGrub2
-from kiwi.bootloader.template.grub2 import BootLoaderTemplateGrub2
 from kiwi.utils.sysconfig import SysConfig
 
 from kiwi.exceptions import (
@@ -87,9 +87,7 @@ class TestBootLoaderConfigGrub2:
             return_value='0xffffffff'
         )
 
-        grub_template = BootLoaderTemplateGrub2()
         self.grub2 = Mock()
-        self.grub2.header_hybrid = grub_template.header_hybrid
         kiwi.bootloader.config.grub2.BootLoaderTemplateGrub2 = Mock(
             return_value=self.grub2
         )
@@ -129,6 +127,17 @@ class TestBootLoaderConfigGrub2:
     def setup_method(self, cls, mock_theme, mock_firmware):
         self.setup()
 
+    def test_setup_sysconfig_bootloader_not_impl(self):
+        xml_state = MagicMock()
+        xml_state.build_type.get_firmware = Mock(
+            return_value=None
+        )
+
+        with pytest.raises(NotImplementedError):
+            BootLoaderConfigGrub2(
+                xml_state=xml_state, root_dir='root_dir'
+            ).setup_sysconfig_bootloader()
+
     @patch('kiwi.bootloader.config.grub2.Path.which')
     def test_post_init_grub2_boot_directory(self, mock_which):
         Defaults.set_platform_name('i686')
@@ -253,7 +262,6 @@ class TestBootLoaderConfigGrub2:
         mock_exists.return_value = True
         self.bootloader.post_init(None)
         assert self.bootloader.multiboot is True
-        assert self.bootloader.hybrid_boot is False
         assert self.bootloader.xen_guest is False
 
     @patch('os.path.exists')
@@ -268,7 +276,6 @@ class TestBootLoaderConfigGrub2:
         mock_exists.return_value = True
         self.bootloader.post_init(None)
         assert self.bootloader.multiboot is False
-        assert self.bootloader.hybrid_boot is False
         assert self.bootloader.xen_guest is True
 
     @patch.object(BootLoaderConfigGrub2, '_setup_default_grub')
@@ -602,8 +609,6 @@ class TestBootLoaderConfigGrub2:
             'GRUB_THEME': '/boot/grub2/themes/openSUSE/theme.txt',
             'GRUB_TIMEOUT': 10,
             'GRUB_TIMEOUT_STYLE': 'countdown',
-            'GRUB_USE_INITRDEFI': 'true',
-            'GRUB_USE_LINUXEFI': 'true',
             'SUSE_BTRFS_SNAPSHOT_BOOTING': 'true',
             'GRUB_DEFAULT': 'saved'
         }
@@ -743,6 +748,49 @@ class TestBootLoaderConfigGrub2:
             call('SUSE_REMOVE_LINUX_ROOT_PARAM', 'true'),
         ]
 
+    @patch('os.path.exists')
+    @patch('kiwi.bootloader.config.grub2.SysConfig')
+    @patch('kiwi.bootloader.config.grub2.Command.run')
+    def test_setup_default_grub_use_of_bls(
+        self, mock_Command_run, mock_sysconfig, mock_exists
+    ):
+        grep_grub_option = Mock()
+        grep_grub_option.returncode = 0
+        mock_Command_run.return_value = grep_grub_option
+        mock_exists.return_value = False
+        grub_default = SysConfig('some-file')
+        grub_default.write = Mock()
+        mock_sysconfig.return_value = grub_default
+        mock_exists.return_value = True
+        self.bootloader.terminal_input = 'serial'
+        self.bootloader.terminal_output = 'gfxterm'
+        self.bootloader.theme = 'openSUSE'
+        self.bootloader.displayname = 'Bob'
+        self.bootloader.bls = True
+        self.firmware.efi_mode.return_value = 'efi'
+
+        self.bootloader._setup_default_grub()
+
+        mock_sysconfig.assert_called_once_with('root_dir/etc/default/grub')
+        grub_default.write.assert_called_once_with()
+
+        assert grub_default.data_dict == {
+            'GRUB_BACKGROUND': '/boot/grub2/themes/openSUSE/background.png',
+            'GRUB_CMDLINE_LINUX_DEFAULT': '"some-cmdline"',
+            'GRUB_DISTRIBUTOR': '"Bob"',
+            'GRUB_ENABLE_BLSCFG': 'true',
+            'GRUB_ENABLE_CRYPTODISK': 'y',
+            'GRUB_GFXMODE': '800x600',
+            'GRUB_SERIAL_COMMAND': '"serial --speed=38400"',
+            'GRUB_TERMINAL_INPUT': '"serial"',
+            'GRUB_TERMINAL_OUTPUT': '"gfxterm"',
+            'GRUB_THEME': '/boot/grub2/themes/openSUSE/theme.txt',
+            'GRUB_TIMEOUT': 10,
+            'GRUB_TIMEOUT_STYLE': 'countdown',
+            'SUSE_BTRFS_SNAPSHOT_BOOTING': 'true',
+            'GRUB_DEFAULT': 'saved'
+        }
+
     @patch('os.path.exists')
     @patch('kiwi.bootloader.config.grub2.SysConfig')
     def test_setup_sysconfig_bootloader(self, mock_sysconfig, mock_exists):
@@ -889,7 +937,7 @@ class TestBootLoaderConfigGrub2:
         self.bootloader.multiboot = True
         self.bootloader.setup_live_image_config(self.mbrid)
         self.grub2.get_multiboot_iso_template.assert_called_once_with(
-            True, False, False, None
+            True, True, False, None
         )
 
     @patch.object(BootLoaderConfigGrub2, '_copy_grub_config_to_efi_path')
@@ -905,7 +953,7 @@ class TestBootLoaderConfigGrub2:
         self.bootloader.multiboot = False
         self.bootloader.setup_live_image_config(self.mbrid)
         self.grub2.get_iso_template.assert_called_once_with(
-            True, True, True, True, None
+            True, True, True, None
         )
         mock_copy_grub_config_to_efi_path.assert_called_once_with(
             'root_dir', 'earlyboot.cfg', 'iso'
@@ -998,32 +1046,11 @@ class TestBootLoaderConfigGrub2:
             mock_copy_grub_config_to_efi_path.assert_called_once_with(
                 'efi_mount_point', 'earlyboot.cfg'
             )
-            assert file_handle_grub.write.call_args_list == [
-                # first write of grub.cfg, adapting to linux/initrd as variables
-                call(
-                    'set linux=linux\n'
-                    'set initrd=initrd\n'
-                    'if [ "${grub_cpu}" = "x86_64" -o '
-                    '"${grub_cpu}" = "i386" ]; then\n'
-                    '    if [ "${grub_platform}" = "efi" ]; then\n'
-                    '        set linux=linuxefi\n'
-                    '        set initrd=initrdefi\n'
-                    '    fi\n'
-                    'fi\n'
-                    'export linux initrd\n'
-                ),
-                call(
-                    'root=rootdev nomodeset console=ttyS0 console=tty0'
-                    '\n'
-                    'root=PARTUUID=xx'
-                ),
-                # second write of grub.cfg, setting overlay root
-                call(
-                    'root=overlay:UUID=ID nomodeset console=ttyS0 console=tty0'
-                    '\n'
-                    'root=overlay:UUID=ID'
-                )
-            ]
+            file_handle_grub.write.assert_called_once_with == (
+                'root=overlay:UUID=ID nomodeset console=ttyS0 console=tty0'
+                '\n'
+                'root=overlay:UUID=ID'
+            )
             file_handle_grubenv.write.assert_called_once_with(
                 'root=overlay:UUID=ID'
             )
@@ -1048,63 +1075,6 @@ class TestBootLoaderConfigGrub2:
             assert 'initrd /initrd' in \
                 file_handle_menu.write.call_args_list[1][0][0].split(os.linesep)
 
-    @patch.object(BootLoaderConfigGrub2, '_mount_system')
-    @patch.object(BootLoaderConfigGrub2, '_copy_grub_config_to_efi_path')
-    @patch('kiwi.bootloader.config.grub2.Command.run')
-    @patch('kiwi.bootloader.config.grub2.Path.which')
-    def test_setup_disk_image_config_validate_linuxefi(
-        self, mock_Path_which, mock_Command_run,
-        mock_copy_grub_config_to_efi_path, mock_mount_system
-    ):
-        mock_Path_which.return_value = '/path/to/grub2-mkconfig'
-        self.firmware.efi_mode = Mock(
-            return_value='uefi'
-        )
-        self.bootloader.root_mount = Mock()
-        self.bootloader.root_mount.mountpoint = 'root_mount_point'
-        self.bootloader.efi_mount = Mock()
-        self.bootloader.efi_mount.mountpoint = 'efi_mount_point'
-        with patch('builtins.open', create=True) as mock_open:
-            mock_open.return_value = MagicMock(spec=io.IOBase)
-            file_handle = mock_open.return_value.__enter__.return_value
-            file_handle.read.return_value = os.linesep.join(
-                [
-                    '\tlinuxefi ${rel_dirname}/${basename} ...',
-                    '\tlinux ${rel_dirname}/${basename} ...',
-                    '\tlinux16 ${rel_dirname}/${basename} ...',
-                    '\tinitrdefi ${rel_dirname}/${initrd}',
-                    '\tinitrd ${rel_dirname}/${initrd}',
-                    '\tinitrd16 ${rel_dirname}/${initrd}'
-                ]
-            )
-            self.bootloader.setup_disk_image_config(
-                boot_options={
-                    'root_device': 'rootdev', 'boot_device': 'bootdev'
-                }
-            )
-            assert file_handle.write.call_args_list == [
-                call(
-                    'set linux=linux\n'
-                    'set initrd=initrd\n'
-                    'if [ "${grub_cpu}" = "x86_64" -o '
-                    '"${grub_cpu}" = "i386" ]; then\n'
-                    '    if [ "${grub_platform}" = "efi" ]; then\n'
-                    '        set linux=linuxefi\n'
-                    '        set initrd=initrdefi\n'
-                    '    fi\n'
-                    'fi\n'
-                    'export linux initrd\n'
-                ),
-                call(
-                    '\t$linux ${rel_dirname}/${basename} ...\n'
-                    '\t$linux ${rel_dirname}/${basename} ...\n'
-                    '\t$linux ${rel_dirname}/${basename} ...\n'
-                    '\t$initrd ${rel_dirname}/${initrd}\n'
-                    '\t$initrd ${rel_dirname}/${initrd}\n'
-                    '\t$initrd ${rel_dirname}/${initrd}'
-                )
-            ]
-
     @patch.object(BootLoaderConfigGrub2, '_copy_grub_config_to_efi_path')
     def test_setup_install_image_config_standard(
         self, mock_copy_grub_config_to_efi_path
@@ -1116,7 +1086,7 @@ class TestBootLoaderConfigGrub2:
         self.bootloader.multiboot = False
         self.bootloader.setup_install_image_config(self.mbrid)
         self.grub2.get_install_template.assert_called_once_with(
-            True, True, False, False, True
+            True, True, False, True
         )
         mock_copy_grub_config_to_efi_path.assert_called_once_with(
             'root_dir', 'earlyboot.cfg', 'iso'
