@@ -1,9 +1,9 @@
 import io
-from mock import (
+from unittest.mock import (
     patch, call, MagicMock
 )
 from pytest import raises
-import mock
+import unittest.mock as mock
 
 from kiwi.bootloader.install.grub2 import BootLoaderInstallGrub2
 from kiwi.defaults import Defaults
@@ -11,7 +11,8 @@ from kiwi.defaults import Defaults
 from kiwi.exceptions import (
     KiwiBootLoaderGrubInstallError,
     KiwiBootLoaderGrubDataError,
-    KiwiBootLoaderGrubPlatformError
+    KiwiBootLoaderGrubPlatformError,
+    KiwiBootLoaderDiskPasswordError
 )
 
 
@@ -171,7 +172,7 @@ class TestBootLoaderInstallGrub2:
         self.bootloader.root_mount.mount.assert_called_once_with(
             options=['subvol=root']
         )
-        self.bootloader.boot_mount.mount.assert_called_once_with()
+        self.boot_mount.mount.assert_called_once_with()
         mock_glob.assert_called_once_with(
             'tmp_root/boot/*/grubenv'
         )
@@ -219,7 +220,7 @@ class TestBootLoaderInstallGrub2:
         self.bootloader.root_mount.mount.assert_called_once_with(
             options=['subvol=root']
         )
-        self.bootloader.boot_mount.mount.assert_called_once_with()
+        self.boot_mount.mount.assert_called_once_with()
         assert mock_command.call_args_list == [
             call(
                 [
@@ -263,10 +264,10 @@ class TestBootLoaderInstallGrub2:
         mock_mount_manager.side_effect = side_effect
 
         self.bootloader.install()
-        self.bootloader.root_mount.mount.assert_called_once_with(
+        self.root_mount.mount.assert_called_once_with(
             options=['subvol=root']
         )
-        self.bootloader.boot_mount.mount.assert_called_once_with()
+        self.boot_mount.mount.assert_called_once_with()
         mock_wipe.assert_called_once_with(
             'tmp_root/boot/grub2/grubenv'
         )
@@ -304,10 +305,10 @@ class TestBootLoaderInstallGrub2:
         mock_mount_manager.side_effect = side_effect
 
         self.bootloader.install()
-        self.bootloader.root_mount.mount.assert_called_once_with(
+        self.root_mount.mount.assert_called_once_with(
             options=['subvol=root']
         )
-        self.bootloader.boot_mount.mount.assert_called_once_with()
+        self.boot_mount.mount.assert_called_once_with()
         mock_wipe.assert_called_once_with(
             'tmp_root/boot/grub2/grubenv'
         )
@@ -448,8 +449,16 @@ class TestBootLoaderInstallGrub2:
             filename='shim-install', root_dir='tmp_root'
         )
 
-    @patch('os.path.isfile')
-    def test_set_disk_password(self, mock_os_path_is_file):
+    @patch('kiwi.bootloader.install.grub2.Command.run')
+    @patch('kiwi.bootloader.install.grub2.MountManager')
+    def test_set_disk_password(self, mock_mount_manager, mock_command):
+        self.boot_mount.device = self.root_mount.device
+
+        def side_effect(device, mountpoint=None):
+            return self.mount_managers.pop()
+
+        mock_mount_manager.side_effect = side_effect
+
         self.bootloader.root_mount = MagicMock()
         self.bootloader.root_mount.mountpoint = 'root_mountpoint'
         with patch('builtins.open', create=True) as mock_open:
@@ -463,25 +472,20 @@ class TestBootLoaderInstallGrub2:
 
     @patch('kiwi.bootloader.install.grub2.Command.run')
     @patch('kiwi.bootloader.install.grub2.MountManager')
-    @patch('kiwi.bootloader.install.grub2.Defaults.get_grub_path')
-    @patch('os.path.exists')
-    def test_destructor(
-        self, mock_exists, mock_grub_path, mock_mount_manager, mock_command
+    @patch('kiwi.bootloader.install.grub2.ExitStack')
+    def test_set_disk_password_failed_to_open_grub_config(
+        self, mock_ExitStack, mock_mount_manager, mock_command
     ):
-        mock_exists.return_value = True
-        self.firmware.efi_mode.return_value = 'uefi'
+        self.boot_mount.device = self.root_mount.device
 
         def side_effect(device, mountpoint=None):
             return self.mount_managers.pop()
 
         mock_mount_manager.side_effect = side_effect
+        self.bootloader.root_mount = MagicMock()
+        self.bootloader.root_mount.mountpoint = 'root_mountpoint'
 
-        self.bootloader.install()
-        self.bootloader.__del__()
-
-        self.device_mount.umount.assert_called_once_with()
-        self.proc_mount.umount.assert_called_once_with()
-        self.sysfs_mount.umount.assert_called_once_with()
-        self.efi_mount.umount.assert_called_once_with()
-        self.boot_mount.umount.assert_called_once_with()
-        self.root_mount.umount.assert_called_once_with()
+        with patch('builtins.open', create=True) as mock_open:
+            mock_open.side_effect = IOError()
+            with raises(KiwiBootLoaderDiskPasswordError):
+                self.bootloader.set_disk_password('credentials')
