@@ -1,13 +1,20 @@
-from mock import patch
-from pytest import raises
+import logging
+from unittest.mock import patch
+from pytest import (
+    raises, fixture
+)
 
 from kiwi.defaults import Defaults
 from kiwi.iso_tools.xorriso import IsoToolsXorrIso
 
-from kiwi.exceptions import KiwiFileNotFound, KiwiIsoToolError
+from kiwi.exceptions import KiwiIsoToolError
 
 
 class TestIsoToolsXorrIso:
+    @fixture(autouse=True)
+    def inject_fixtures(self, caplog):
+        self._caplog = caplog
+
     def setup(self):
         Defaults.set_platform_name('x86_64')
         self.iso_tool = IsoToolsXorrIso('source-dir')
@@ -26,60 +33,22 @@ class TestIsoToolsXorrIso:
         with raises(KiwiIsoToolError):
             self.iso_tool.get_tool_name()
 
-    @patch('kiwi.iso_tools.xorriso.Path.which')
-    def test_init_iso_creation_parameters_isolinux_fail_on_isohdpfx_not_found(self, mock_which):
-        mock_which.return_value = None
-        with raises(KiwiFileNotFound):
+    @patch('os.path.exists')
+    def test_init_iso_creation_parameters_no_hybrid_mbr(
+        self, mock_os_path_exists
+    ):
+        mock_os_path_exists.return_value = False
+        with self._caplog.at_level(logging.WARNING):
             self.iso_tool.init_iso_creation_parameters(
                 {
                     'mbr_id': 'app_id',
                     'publisher': 'org',
                     'preparer': 'preparer',
-                    'volume_id': 'vol_id'
+                    'volume_id': 'vol_id',
+                    'efi_mode': 'uefi'
                 }
             )
-
-    @patch('kiwi.iso_tools.xorriso.Path.which')
-    def test_init_iso_creation_parameters_isolinux(self, mock_which):
-        mock_which.return_value = '/usr/share/syslinux/isohdpfx.bin'
-        self.iso_tool.init_iso_creation_parameters(
-            {
-                'mbr_id': 'app_id',
-                'publisher': 'org',
-                'preparer': 'preparer',
-                'volume_id': 'vol_id'
-            }
-        )
-        mock_which.assert_called_once_with(
-            'isohdpfx.bin', [
-                '/usr/share/syslinux',
-                '/usr/lib/syslinux/bios',
-                '/usr/lib/syslinux/modules/bios',
-                '/usr/lib/ISOLINUX'
-            ]
-        )
-        assert self.iso_tool.iso_parameters == [
-            '-application_id', 'app_id',
-            '-publisher', 'org',
-            '-preparer_id', 'preparer',
-            '-volid', 'vol_id',
-            '-joliet', 'on',
-            '-padding', '0'
-        ]
-        assert self.iso_tool.iso_loaders == [
-            '-boot_image', 'isolinux',
-            'bin_path=boot/x86_64/loader/isolinux.bin',
-            '-boot_image', 'isolinux',
-            'system_area=/usr/share/syslinux/isohdpfx.bin',
-            '-boot_image', 'isolinux', 'partition_table=on',
-            '-boot_image', 'any', 'partition_offset=16',
-            '-boot_image', 'any', 'cat_path=boot/x86_64/boot.catalog',
-            '-boot_image', 'any', 'cat_hidden=on',
-            '-boot_image', 'any', 'boot_info_table=on',
-            '-boot_image', 'any', 'platform_id=0x00',
-            '-boot_image', 'any', 'emul_type=no_emulation',
-            '-boot_image', 'any', 'load_size=2048'
-        ]
+            assert 'No hybrid MBR file found' in self._caplog.text
 
     @patch('os.path.exists')
     def test_init_iso_creation_parameters_efi(self, mock_os_path_exists):
@@ -105,7 +74,7 @@ class TestIsoToolsXorrIso:
             '-boot_image', 'grub',
             'bin_path=boot/x86_64/loader/eltorito.img',
             '-boot_image', 'grub',
-            'grub2_mbr=source-dir/boot/x86_64//loader/boot_hybrid.img',
+            'grub2_mbr=source-dir/boot/x86_64/loader/boot_hybrid.img',
             '-boot_image', 'grub', 'grub2_boot_info=on',
             '-boot_image', 'any', 'partition_offset=16',
             '-boot_image', 'any', 'cat_path=boot/x86_64/boot.catalog',
