@@ -1,4 +1,4 @@
-from mock import (
+from unittest.mock import (
     Mock, patch, call
 )
 
@@ -119,6 +119,7 @@ class TestOCIUmoci:
             'workingdir': '/root',
             'expose_ports': ['80', '42'],
             'volumes': ['/var/log', '/tmp'],
+            'stopsignal': 'SIGINT',
             'environment': {'FOO': 'bar', 'PATH': '/bin'},
             'labels': {'a': 'value', 'b': 'value'},
         }
@@ -129,6 +130,7 @@ class TestOCIUmoci:
                 '--config.workingdir=/root', '--config.entrypoint=/bin/bash',
                 '--config.entrypoint=-x', '--config.cmd=ls', '--config.cmd=-l',
                 '--config.volume=/var/log', '--config.volume=/tmp',
+                '--config.stopsignal=SIGINT',
                 '--config.exposedports=80', '--config.exposedports=42',
                 '--config.env=FOO=bar', '--config.env=PATH=/bin',
                 '--config.label=a=value', '--config.label=b=value',
@@ -247,3 +249,12 @@ class TestOCIUmoci:
         mock_Command_run.assert_called_once_with(
             ['umoci', 'gc', '--layout', 'tmpdir/oci_layout']
         )
+
+    @patch('kiwi.oci_tools.umoci.CommandCapabilities.has_option_in_help')
+    def test_context_manager_exit(
+        self, mock_CommandCapabilities_has_option_in_help
+    ):
+        mock_CommandCapabilities_has_option_in_help.return_value = True
+        with OCIUmoci():
+            pass
+            # just pass
