@@ -1,5 +1,5 @@
 import logging
-from mock import patch, call
+from unittest.mock import patch, call
 from pytest import (
     raises, fixture
 )
@@ -108,7 +108,7 @@ class TestPath:
         assert Path.which('some-file') is None
         mock_env.return_value = None
         mock_exists.return_value = True
-        assert Path.which('some-file', ['alternative']) == \
+        assert Path.which('some-file', alternative_lookup_paths=['alternative']) == \
             'alternative/some-file'
         mock_access.return_value = False
         mock_env.return_value = '/usr/local/bin:/usr/bin:/bin'
@@ -134,7 +134,6 @@ class TestPath:
         mock_exists.return_value = False
         with self._caplog.at_level(logging.DEBUG):
             assert Path.which('file') is None
-            print(self._caplog.text)
             assert (
                 '"file": in paths "{0}" exists: "False" mode match: '
                 'not checked'
