@@ -1,9 +1,9 @@
 import logging
-from mock import patch
+from unittest.mock import patch
 from pytest import (
     fixture, raises
 )
-import mock
+import unittest.mock as mock
 
 import kiwi
 
