@@ -3,7 +3,7 @@ import os
 from pytest import (
     raises, fixture
 )
-from mock import (
+from unittest.mock import (
     patch, call, Mock, MagicMock, ANY
 )
 
@@ -254,7 +254,7 @@ class TestSystemPrepare:
             return_value='credentials-file'
         )
         repo = Mock()
-        mock_repo.return_value = repo
+        mock_repo.return_value.__enter__.return_value = repo
 
         self.system.setup_repositories(
             clear_cache=True,
@@ -324,7 +324,7 @@ class TestSystemPrepare:
             return_value='uri-alias'
         )
         repo = Mock()
-        mock_repo.return_value = repo
+        mock_repo.return_value.__enter__.return_value = repo
         with self._caplog.at_level(logging.WARNING):
             self.system.setup_repositories()
 
@@ -499,23 +499,26 @@ class TestSystemPrepare:
         self.system.update_system(self.manager)
         self.manager.update.assert_called_once_with()
 
-    def test_destructor(self):
-        self.system.__del__()
-        self.system.root_bind.cleanup.assert_called_once_with()
+    @patch('kiwi.system.prepare.RootBind')
+    @patch('kiwi.system.prepare.RootInit')
+    @patch('kiwi.logger.Logger.get_logfile')
+    def test_context_manager_exit(
+        self, mock_get_logfile, mock_RootInit, mock_RootBind
+    ):
+        root_bind = Mock()
+        mock_RootBind.return_value = root_bind
+        root_import = Mock()
+        with SystemPrepare(
+            xml_state=self.state, root_dir='root_dir', allow_existing=True
+        ) as system:
+            system.root_import = root_import
+        root_bind.cleanup.assert_called_once_with()
+        root_import.overlay_finalize.assert_called_once_with(self.state)
 
     @patch('kiwi.system.prepare.Repository.new')
     @patch('kiwi.system.prepare.PackageManager.new')
     def test_clean_package_manager_leftovers(self, mock_manager, mock_repo):
         manager = Mock()
-        mock_manager.return_value = manager
+        mock_manager.return_value.__enter__.return_value = manager
         self.system.clean_package_manager_leftovers()
         manager.clean_leftovers.assert_called_once_with()
-
-    def test_destructor_raising(self):
-        self.system.root_bind = Mock()
-        self.system.root_bind.cleanup.side_effect = ValueError("nothing")
-        with self._caplog.at_level(logging.INFO):
-            del self.system
-            assert 'Cleaning up SystemPrepare instance' in self._caplog.text
-            assert 'Cleaning up SystemPrepare instance failed, '
-            'got an exception of type ValueError: nothing' in self._caplog.text
