@@ -1,5 +1,5 @@
 import logging
-from mock import (
+from unittest.mock import (
     patch, MagicMock, mock_open, call
 )
 from pytest import (
