@@ -1,6 +1,6 @@
 import sys
 
-from mock import (
+from unittest.mock import (
     patch, call, Mock, MagicMock
 )
 
