@@ -1,7 +1,7 @@
 import os
 import sys
 import logging
-from mock import (
+from unittest.mock import (
     patch, call, Mock, mock_open
 )
 from pytest import (
@@ -73,6 +73,7 @@ class TestResultBundleTask:
         self.task.command_args['--id'] = 'Build_42'
         self.task.command_args['--zsync-source'] = None
         self.task.command_args['--package-as-rpm'] = None
+        self.task.command_args['--bundle-format'] = None
 
     def test_process_invalid_bundle_directory(self):
         self._init_command_args()
@@ -89,8 +90,13 @@ class TestResultBundleTask:
     @patch('kiwi.tasks.result_bundle.Compress')
     @patch('kiwi.tasks.result_bundle.Checksum')
     @patch('os.path.exists')
+    @patch('os.path.islink')
+    @patch('os.unlink')
+    @patch('os.symlink')
+    @patch('os.readlink')
     def test_process_result_bundle(
-        self, mock_exists, mock_checksum, mock_compress,
+        self, mock_os_readlink, mock_os_symlink, mock_os_unlink,
+        mock_os_path_islink, mock_exists, mock_checksum, mock_compress,
         mock_path_which, mock_path_create, mock_command, mock_load
     ):
         # This file won't be copied with build id
@@ -102,7 +108,7 @@ class TestResultBundleTask:
         checksum = Mock()
         compress = Mock()
         mock_path_which.return_value = 'zsyncmake'
-        compress.compressed_filename = 'compressed_filename'
+        compress.xz.return_value = 'compressed_filename'
         mock_compress.return_value = compress
         mock_checksum.return_value = checksum
         mock_exists.return_value = False
@@ -111,6 +117,12 @@ class TestResultBundleTask:
         self.task.command_args['bundle'] = True
         self.task.command_args['--zsync-source'] = 'http://example.com/zsync'
 
+        command_result = Mock()
+        command_result.output = "some mime is text"
+        mock_command.return_value = command_result
+
+        mock_os_readlink.return_value = 'readlinked'
+
         m_open = mock_open()
         with patch('builtins.open', m_open, create=True):
             self.task.process()
@@ -124,22 +136,38 @@ class TestResultBundleTask:
                 'cp', 'test-image-1.2.3',
                 os.sep.join([self.abs_bundle_dir, 'test-image-1.2.3-Build_42'])
             ]),
+            call([
+                'cp', 'test-image-noversion',
+                os.sep.join([self.abs_bundle_dir, 'test-image-noversion'])
+            ]),
+            call([
+                'file',
+                os.sep.join([self.abs_bundle_dir, 'test-image-1.2.3-Build_42'])
+            ]),
+            call([
+                'sed', '-ie', 's/test-image-1.2.3/readlinked/g',
+                os.sep.join([self.abs_bundle_dir, 'test-image-1.2.3-Build_42'])
+            ]),
+            call([
+                'file',
+                os.sep.join([self.abs_bundle_dir, 'test-image-noversion'])
+            ]),
+            call([
+                'sed', '-ie', 's/test-image-1.2.3/readlinked/g',
+                os.sep.join([self.abs_bundle_dir, 'test-image-noversion'])
+            ]),
             call([
                 'zsyncmake', '-e',
                 '-u', 'http://example.com/zsync/compressed_filename',
                 '-o', 'compressed_filename.zsync',
                 'compressed_filename'
-            ]),
-            call([
-                'cp', 'test-image-noversion',
-                os.sep.join([self.abs_bundle_dir, 'test-image-noversion'])
             ])
         ]
         mock_compress.assert_called_once_with(
             os.sep.join([self.abs_bundle_dir, 'test-image-1.2.3-Build_42'])
         )
         mock_checksum.assert_called_once_with(
-            compress.compressed_filename
+            'compressed_filename'
         )
         checksum.sha256.assert_called_once_with()
         m_open.return_value.write.assert_called_once_with(
@@ -160,15 +188,19 @@ class TestResultBundleTask:
     @patch('os.chdir')
     @patch('os.unlink')
     @patch('glob.iglob')
+    @patch('os.path.islink')
+    @patch('os.symlink')
+    @patch('os.readlink')
     def test_process_result_bundle_as_rpm(
-        self, mock_iglob, mock_unlink, mock_chdir, mock_exists, mock_checksum,
+        self, mock_os_readlink, mock_os_symlink, mock_os_path_islink,
+        mock_iglob, mock_unlink, mock_chdir, mock_exists, mock_checksum,
         mock_compress, mock_path_wipe, mock_path_which, mock_path_create,
         mock_command, mock_load, mock_Privileges_check_for_root_permissions
     ):
         checksum = Mock()
         compress = Mock()
         mock_path_which.return_value = 'zsyncmake'
-        compress.compressed_filename = 'compressed_filename'
+        compress.xz.return_value = 'compressed_filename'
         mock_compress.return_value = compress
         mock_checksum.return_value = checksum
         mock_exists.return_value = False
@@ -195,6 +227,14 @@ class TestResultBundleTask:
                     )
                 ]
             ),
+            call(
+                [
+                    'file',
+                    os.sep.join(
+                        [self.abs_bundle_dir, 'test-image-1.2.3-Build_42']
+                    )
+                ]
+            ),
             call(
                 [
                     'rpmbuild', '--nodeps', '--nocheck', '--rmspec', '-bb',
@@ -208,16 +248,20 @@ class TestResultBundleTask:
         mock_chdir.assert_called_once_with(
             self.abs_bundle_dir
         )
-        mock_unlink.assert_called_once_with(
-            os.sep.join([self.abs_bundle_dir, 'test-image-1.2.3-Build_42'])
-        )
+        assert mock_unlink.called
 
     @patch('kiwi.tasks.result_bundle.Result.load')
     @patch('kiwi.tasks.result_bundle.Command.run')
     @patch('kiwi.tasks.result_bundle.Path.create')
     @patch('os.path.exists')
+    @patch('os.path.islink')
+    @patch('os.unlink')
+    @patch('os.symlink')
+    @patch('os.readlink')
     def test_process_result_bundle_with_bundle_format(
-        self, mock_exists, mock_path_create, mock_command, mock_load
+        self, mock_os_readlink, mock_os_symlink, mock_os_unlink,
+        mock_os_path_islink, mock_exists, mock_path_create, mock_command,
+        mock_load
     ):
         self.xml_state.profiles = None
         self.xml_state.host_architecture = 'x86_64'
@@ -242,22 +286,95 @@ class TestResultBundleTask:
 
         self.task.process()
 
-        mock_command.assert_called_once_with(
-            [
-                'cp',
-                '/tmp/mytest/Leap-15.2.x86_64-1.15.2.raw',
-                os.sep.join(
-                    [self.abs_bundle_dir, 'Leap-15.2-oem:1.raw']
-                )
-            ]
-        )
+        assert mock_command.call_args_list == [
+            call(
+                [
+                    'cp',
+                    '/tmp/mytest/Leap-15.2.x86_64-1.15.2.raw',
+                    os.sep.join(
+                        [self.abs_bundle_dir, 'Leap-15.2-oem:1.raw']
+                    )
+                ]
+            ),
+            call(
+                [
+                    'file',
+                    os.sep.join(
+                        [self.abs_bundle_dir, 'Leap-15.2-oem:1.raw']
+                    )
+                ]
+            )
+        ]
 
     @patch('kiwi.tasks.result_bundle.Result.load')
     @patch('kiwi.tasks.result_bundle.Command.run')
     @patch('kiwi.tasks.result_bundle.Path.create')
     @patch('os.path.exists')
+    @patch('os.path.islink')
+    @patch('os.unlink')
+    @patch('os.symlink')
+    @patch('os.readlink')
+    def test_process_result_bundle_with_bundle_format_from_commandline(
+        self, mock_os_readlink, mock_os_symlink, mock_os_unlink,
+        mock_os_path_islink, mock_exists, mock_path_create, mock_command,
+        mock_load
+    ):
+        self.xml_state.profiles = None
+        self.xml_state.host_architecture = 'x86_64'
+        self.xml_state.get_build_type_name = Mock(
+            return_value='oem'
+        )
+        self.xml_state.xml_data.get_name = Mock(
+            return_value='Leap-15.2'
+        )
+
+        result = Result(self.xml_state)
+        result.add(
+            key='disk_image',
+            filename='/tmp/mytest/Leap-15.2.x86_64-1.15.2.raw',
+            use_for_bundle=True, compress=False, shasum=False
+        )
+
+        mock_exists.return_value = False
+        mock_load.return_value = result
+        self._init_command_args()
+
+        self.task.command_args['--bundle-format'] = '%N-%T:%M'
+
+        self.task.process()
+
+        assert mock_command.call_args_list == [
+            call(
+                [
+                    'cp',
+                    '/tmp/mytest/Leap-15.2.x86_64-1.15.2.raw',
+                    os.sep.join(
+                        [self.abs_bundle_dir, 'Leap-15.2-oem:1.raw']
+                    )
+                ]
+            ),
+            call(
+                [
+                    'file',
+                    os.sep.join(
+                        [self.abs_bundle_dir, 'Leap-15.2-oem:1.raw']
+                    )
+                ]
+            )
+        ]
+
+    @patch('kiwi.tasks.result_bundle.Result.load')
+    @patch('kiwi.tasks.result_bundle.Command.run')
+    @patch('kiwi.tasks.result_bundle.Path.create')
+    @patch('os.path.exists')
+    @patch('os.path.islink')
+    @patch('os.unlink')
+    @patch('os.symlink')
+    @patch('os.readlink')
     def test_process_result_bundle_name_includes_version(
-        self, mock_exists, mock_path_create, mock_command, mock_load
+        self, mock_os_readlink, mock_os_symlink, mock_os_unlink,
+        mock_os_path_islink, mock_exists, mock_path_create, mock_command,
+        mock_load
     ):
         result = Result(self.xml_state)
         result.add(
@@ -280,13 +397,22 @@ class TestResultBundleTask:
         )
         mock_path_create.assert_called_once_with(self.abs_bundle_dir)
         assert mock_command.call_args_list == [
-            call([
-                'cp', 'test-1.2.3-image-1.2.3',
-                os.sep.join([
-                    self.abs_bundle_dir,
-                    'test-1.2.3-image-1.2.3-Build_42'
-                ])
-            ])
+            call(
+                [
+                    'cp', 'test-1.2.3-image-1.2.3',
+                    os.sep.join(
+                        [self.abs_bundle_dir, 'test-1.2.3-image-1.2.3-Build_42']
+                    )
+                ]
+            ),
+            call(
+                [
+                    'file',
+                    os.sep.join(
+                        [self.abs_bundle_dir, 'test-1.2.3-image-1.2.3-Build_42']
+                    )
+                ]
+            )
         ]
 
     @patch('kiwi.tasks.result_bundle.Result.load')
@@ -296,14 +422,19 @@ class TestResultBundleTask:
     @patch('kiwi.tasks.result_bundle.Compress')
     @patch('kiwi.tasks.result_bundle.Checksum')
     @patch('os.path.exists')
+    @patch('os.path.islink')
+    @patch('os.unlink')
+    @patch('os.symlink')
+    @patch('os.readlink')
     def test_process_result_bundle_zsyncmake_missing(
-        self, mock_exists, mock_checksum, mock_compress,
+        self, mock_os_readlink, mock_os_symlink, mock_os_unlink,
+        mock_os_path_islink, mock_exists, mock_checksum, mock_compress,
         mock_path_which, mock_path_create, mock_command, mock_load
     ):
         checksum = Mock()
         compress = Mock()
         mock_path_which.return_value = None
-        compress.compressed_filename = 'compressed_filename'
+        compress.xz.return_value = 'compressed_filename'
         mock_compress.return_value = compress
         mock_checksum.return_value = checksum
         mock_exists.return_value = False
