@@ -1,10 +1,9 @@
 import logging
 import sys
-import mock
 import os
 from pytest import fixture
-from mock import (
-    patch, call
+from unittest.mock import (
+    patch, call, Mock, MagicMock
 )
 
 import kiwi
@@ -27,50 +26,40 @@ class TestSystemBuildTask:
         ]
         self.abs_target_dir = os.path.abspath('some-target')
 
-        kiwi.tasks.system_build.Privileges = mock.Mock()
-        kiwi.tasks.system_build.Path = mock.Mock()
+        kiwi.tasks.system_build.Privileges = Mock()
+        kiwi.tasks.system_build.Path = Mock()
 
-        kiwi.tasks.system_build.Help = mock.Mock(
-            return_value=mock.Mock()
+        kiwi.tasks.system_build.Help = Mock(
+            return_value=Mock()
         )
 
-        self.manager = mock.Mock()
-        self.system_prepare = mock.Mock()
-        self.system_prepare.setup_repositories = mock.Mock(
-            return_value=self.manager
-        )
-
-        self.runtime_checker = mock.Mock()
-        kiwi.tasks.base.RuntimeChecker = mock.Mock(
+        self.runtime_checker = Mock()
+        kiwi.tasks.base.RuntimeChecker = Mock(
             return_value=self.runtime_checker
         )
 
-        kiwi.tasks.system_build.SystemPrepare = mock.Mock(
-            return_value=self.system_prepare
-        )
-
-        self.setup = mock.Mock()
-        kiwi.tasks.system_build.SystemSetup = mock.Mock(
+        self.setup = Mock()
+        kiwi.tasks.system_build.SystemSetup = Mock(
             return_value=self.setup
         )
 
-        self.profile = mock.Mock()
+        self.profile = Mock()
         self.profile.dot_profile = dict()
-        kiwi.tasks.system_build.Profile = mock.Mock(
+        kiwi.tasks.system_build.Profile = Mock(
             return_value=self.profile
         )
 
-        self.result = mock.Mock()
-        self.builder = mock.MagicMock()
-        self.builder.create = mock.Mock(
+        self.result = Mock()
+        self.builder = MagicMock()
+        self.builder.create = Mock(
             return_value=self.result
         )
-        kiwi.tasks.system_build.ImageBuilder.new = mock.Mock(
+        kiwi.tasks.system_build.ImageBuilder.new = Mock(
             return_value=self.builder
         )
 
         self.task = SystemBuildTask()
-        self.task.runtime_config = mock.MagicMock()
+        self.task.runtime_config = MagicMock()
 
     def setup_method(self, cls):
         self.setup()
@@ -105,7 +94,16 @@ class TestSystemBuildTask:
 
     @patch('kiwi.logger.Logger.set_logfile')
     @patch('kiwi.xml_state.XMLState.get_repositories_signing_keys')
-    def test_process_system_build(self, mock_keys, mock_log):
+    @patch('kiwi.tasks.system_build.SystemPrepare')
+    def test_process_system_build(
+        self, mock_SystemPrepare, mock_keys, mock_log
+    ):
+        manager = MagicMock()
+        system_prepare = Mock()
+        system_prepare.setup_repositories = Mock(
+            return_value=manager
+        )
+        mock_SystemPrepare.return_value.__enter__.return_value = system_prepare
         mock_keys.return_value = ['some_key', 'some_other_key']
         self._init_command_args()
         self.task.command_args['build'] = True
@@ -159,17 +157,14 @@ class TestSystemBuildTask:
         self.runtime_checker.\
             check_efi_mode_for_disk_overlay_correctly_setup.\
             assert_called_once_with()
-        self.runtime_checker.\
-            check_architecture_supports_iso_firmware_setup.\
-            assert_called_once_with()
-        self.system_prepare.setup_repositories.assert_called_once_with(
+        system_prepare.setup_repositories.assert_called_once_with(
             False, ['some_key', 'some_other_key'], None
         )
-        self.system_prepare.install_bootstrap.assert_called_once_with(
-            self.manager, []
+        system_prepare.install_bootstrap.assert_called_once_with(
+            manager.__enter__.return_value, []
         )
-        self.system_prepare.install_system.assert_called_once_with(
-            self.manager
+        system_prepare.install_system.assert_called_once_with(
+            manager.__enter__.return_value
         )
         self.profile.create.assert_called_once_with(
             self.abs_target_dir + '/build/image-root/.profile'
@@ -189,10 +184,10 @@ class TestSystemBuildTask:
         self.setup.setup_timezone.assert_called_once_with()
         self.setup.setup_permissions.assert_called_once_with()
         self.setup.setup_selinux_file_contexts.assert_called_once_with()
-        self.system_prepare.pinch_system.assert_has_calls(
+        system_prepare.pinch_system.assert_has_calls(
             [call(force=False), call(force=True)]
         )
-        assert self.system_prepare.clean_package_manager_leftovers.called
+        assert system_prepare.clean_package_manager_leftovers.called
         self.setup.call_image_script.assert_called_once_with()
         self.builder.create.assert_called_once_with()
         self.result.print_results.assert_called_once_with()
@@ -202,36 +197,55 @@ class TestSystemBuildTask:
 
     @patch('kiwi.logger.Logger.set_logfile')
     @patch('kiwi.xml_state.XMLState.get_repositories_signing_keys')
-    def test_process_system_build_add_package(self, mock_keys, mock_log):
+    @patch('kiwi.tasks.system_build.SystemPrepare')
+    def test_process_system_build_add_package(
+        self, mock_SystemPrepare, mock_keys, mock_log
+    ):
+        manager = MagicMock()
+        system_prepare = Mock()
+        system_prepare.setup_repositories = Mock(
+            return_value=manager
+        )
+        mock_SystemPrepare.return_value.__enter__.return_value = system_prepare
         mock_keys.return_value = ['some_key', 'some_other_key']
         self._init_command_args()
         self.task.command_args['--add-package'] = ['vim']
         self.task.process()
-        self.system_prepare.setup_repositories.assert_called_once_with(
+        system_prepare.setup_repositories.assert_called_once_with(
             False, ['some_key', 'some_other_key'], None
         )
-        self.system_prepare.install_packages.assert_called_once_with(
-            self.manager, ['vim']
+        system_prepare.install_packages.assert_called_once_with(
+            manager.__enter__.return_value, ['vim']
         )
 
     @patch('kiwi.logger.Logger.set_logfile')
     @patch('kiwi.xml_state.XMLState.get_repositories_signing_keys')
-    def test_process_system_update_delete_package(self, mock_keys, mock_log):
+    @patch('kiwi.tasks.system_build.SystemPrepare')
+    def test_process_system_update_delete_package(
+        self, mock_SystemPrepare, mock_keys, mock_log
+    ):
+        manager = MagicMock()
+        system_prepare = Mock()
+        system_prepare.setup_repositories = Mock(
+            return_value=manager
+        )
+        mock_SystemPrepare.return_value.__enter__.return_value = system_prepare
         mock_keys.return_value = ['some_key', 'some_other_key']
         self._init_command_args()
         self.task.command_args['--delete-package'] = ['vim']
         self.task.process()
-        self.system_prepare.setup_repositories.assert_called_once_with(
+        system_prepare.setup_repositories.assert_called_once_with(
             False, ['some_key', 'some_other_key'], None
         )
-        self.system_prepare.delete_packages.assert_called_once_with(
-            self.manager, ['vim']
+        system_prepare.delete_packages.assert_called_once_with(
+            manager.__enter__.return_value, ['vim']
         )
 
     @patch('kiwi.xml_state.XMLState.set_container_config_tag')
     @patch('kiwi.logger.Logger.set_logfile')
+    @patch('kiwi.tasks.system_build.SystemPrepare')
     def test_process_system_build_prepare_stage_set_container_tag(
-        self, mock_log, mock_set_container_tag
+        self, mock_SystemPrepare, mock_log, mock_set_container_tag
     ):
         self._init_command_args()
         self.task.command_args['--set-container-tag'] = 'new_tag'
@@ -242,8 +256,9 @@ class TestSystemBuildTask:
 
     @patch('kiwi.xml_state.XMLState.add_container_config_label')
     @patch('kiwi.logger.Logger.set_logfile')
+    @patch('kiwi.tasks.system_build.SystemPrepare')
     def test_process_system_build_add_container_label(
-        self, mock_log, mock_add_container_label
+        self, mock_SystemPrepare, mock_log, mock_add_container_label
     ):
         self._init_command_args()
         self.task.command_args['--add-container-label'] = [
@@ -256,8 +271,9 @@ class TestSystemBuildTask:
         ])
 
     @patch('kiwi.logger.Logger.set_logfile')
+    @patch('kiwi.tasks.system_build.SystemPrepare')
     def test_process_system_build_add_container_label_invalid_format(
-        self, mock_logger
+        self, mock_SystemPrepare, mock_logger
     ):
         self._init_command_args()
         self.task.command_args['--add-container-label'] = ['newLabel:value']
@@ -266,8 +282,9 @@ class TestSystemBuildTask:
 
     @patch('kiwi.xml_state.XMLState.set_derived_from_image_uri')
     @patch('kiwi.logger.Logger.set_logfile')
+    @patch('kiwi.tasks.system_build.SystemPrepare')
     def test_process_system_build_prepare_stage_set_derived_from_uri(
-        self, mock_log, mock_set_derived_from_uri
+        self, mock_SystemPrepare, mock_log, mock_set_derived_from_uri
     ):
         self._init_command_args()
         self.task.command_args['--set-container-derived-from'] = 'file:///new'
@@ -280,8 +297,10 @@ class TestSystemBuildTask:
     @patch('kiwi.logger.Logger.set_logfile')
     @patch('os.path.isfile')
     @patch('os.unlink')
+    @patch('kiwi.tasks.system_build.SystemPrepare')
     def test_process_system_build_prepare_stage_set_repo(
-        self, mock_os_unlink, mock_os_path_is_file, mock_log, mock_set_repo
+        self, mock_SystemPrepare, mock_os_unlink, mock_os_path_is_file,
+        mock_log, mock_set_repo
     ):
         mock_os_path_is_file.return_value = False
         self._init_command_args()
@@ -310,8 +329,9 @@ class TestSystemBuildTask:
 
     @patch('kiwi.xml_state.XMLState.add_repository')
     @patch('kiwi.logger.Logger.set_logfile')
+    @patch('kiwi.tasks.system_build.SystemPrepare')
     def test_process_system_build_prepare_stage_add_repo(
-        self, mock_log, mock_add_repo
+        self, mock_SystemPrepare, mock_log, mock_add_repo
     ):
         self._init_command_args()
         self.task.command_args['--add-repo'] = [
@@ -366,8 +386,9 @@ class TestSystemBuildTask:
 
     @patch('kiwi.xml_state.XMLState.delete_repository_sections')
     @patch('kiwi.logger.Logger.set_logfile')
+    @patch('kiwi.tasks.system_build.SystemPrepare')
     def test_process_system_prepare_ignore_repos(
-        self, mock_log, mock_delete_repos
+        self, mock_SystemPrepare, mock_log, mock_delete_repos
     ):
         self._init_command_args()
         self.task.command_args['--ignore-repos'] = True
@@ -376,8 +397,9 @@ class TestSystemBuildTask:
 
     @patch('kiwi.xml_state.XMLState.delete_repository_sections_used_for_build')
     @patch('kiwi.logger.Logger.set_logfile')
+    @patch('kiwi.tasks.system_build.SystemPrepare')
     def test_process_system_prepare_ignore_repos_used_for_build(
-        self, mock_log, mock_delete_repos
+        self, mock_SystemPrepare, mock_log, mock_delete_repos
     ):
         self._init_command_args()
         self.task.command_args['--ignore-repos-used-for-build'] = True
