@@ -1,6 +1,5 @@
 import datetime
-import logging
-from mock import (
+from unittest.mock import (
     patch, call, Mock, mock_open
 )
 from pytest import (
@@ -9,6 +8,8 @@ from pytest import (
 from lxml import etree
 from xml.dom import minidom
 
+import pytest
+
 from kiwi.volume_manager.btrfs import VolumeManagerBtrfs
 from kiwi.xml_state import volume_type
 
@@ -84,6 +85,11 @@ class TestVolumeManagerBtrfs:
         self.volume_manager.post_init({'root_is_snapshot': True})
         assert self.volume_manager.custom_args['root_is_snapshot'] is False
 
+    def test_fails_to_get_mountpoint_without_mountpoint(self):
+        self.volume_manager.mountpoint = ''
+        with pytest.raises(KiwiVolumeManagerSetupError):
+            self.volume_manager.get_mountpoint()
+
     @patch('os.path.exists')
     @patch('kiwi.volume_manager.btrfs.Command.run')
     @patch('kiwi.volume_manager.btrfs.FileSystem.new')
@@ -387,51 +393,6 @@ class TestVolumeManagerBtrfs:
             options=['subvol=@/var/tmp']
         )
 
-    @patch('os.chmod')
-    @patch('os.path.exists')
-    @patch('kiwi.volume_manager.btrfs.Command.run')
-    @patch('kiwi.volume_manager.btrfs.FileSystem.new')
-    @patch('kiwi.volume_manager.btrfs.MappedDevice')
-    @patch('kiwi.volume_manager.btrfs.MountManager')
-    @patch('kiwi.volume_manager.base.Temporary')
-    def test_remount_volumes(
-        self, mock_Temporary, mock_mount, mock_mapped_device, mock_fs,
-        mock_command, mock_os_exists, mock_os_chmod
-    ):
-        mock_Temporary.return_value.new_dir.return_value.name = \
-            '/var/tmp/kiwi_volumes.xx'
-        toplevel_mount = Mock()
-        toplevel_mount.is_mounted = Mock(
-            return_value=False
-        )
-        mock_mount.return_value = toplevel_mount
-        command_call = Mock()
-        command_call.output = \
-            'ID 258 gen 26 top level 257 path @/.snapshots/1/snapshot'
-        mock_mapped_device.return_value = 'mapped_device'
-        mock_os_exists.return_value = False
-        mock_command.return_value = command_call
-        self.volume_manager.custom_args['root_is_snapshot'] = True
-
-        self.volume_manager.setup()
-        mock_os_chmod.assert_called_once_with(
-            '/var/tmp/kiwi_volumes.xx/@/.snapshots', 0o700
-        )
-        mock_os_exists.return_value = True
-        volume_mount = Mock()
-        volume_mount.mountpoint = \
-            '/var/tmp/kiwi_volumes.xx/@/.snapshots/1/snapshot/var/tmp'
-        volume_mount.get_attributes.return_value = {
-            'subvol_path': '@/var/tmp'
-        }
-        self.volume_manager.subvol_mount_list = [volume_mount]
-
-        self.volume_manager.mount_volumes()
-        self.volume_manager.umount_volumes()
-        self.volume_manager.mount_volumes()
-
-        assert volume_mount.mountpoint == '/var/tmp/kiwi_volumes.xx/var/tmp'
-
     def test_umount_volumes(self):
         self.volume_manager.toplevel_mount = Mock()
         volume_mount = Mock()
@@ -448,32 +409,6 @@ class TestVolumeManagerBtrfs:
         self.volume_manager.toplevel_mount.is_mounted.assert_called_once_with()
         self.volume_manager.toplevel_mount.umount.assert_called_once_with()
 
-    def test_umount_sub_volumes_busy(self):
-        self.volume_manager.toplevel_mount = Mock()
-        volume_mount = Mock()
-        volume_mount.is_mounted = Mock(
-            return_value=True
-        )
-        volume_mount.umount = Mock(
-            return_value=False
-        )
-        self.volume_manager.subvol_mount_list = [volume_mount]
-        assert self.volume_manager.umount_volumes() is False
-
-    def test_umount_toplevel_busy(self):
-        self.volume_manager.toplevel_mount = Mock()
-        volume_mount = Mock()
-        volume_mount.is_mounted = Mock(
-            return_value=True
-        )
-        self.volume_manager.toplevel_mount.is_mounted = Mock(
-            return_value=True
-        )
-        self.volume_manager.toplevel_mount.umount = Mock(
-            return_value=False
-        )
-        assert self.volume_manager.umount_volumes() is False
-
     @patch('kiwi.volume_manager.btrfs.SysConfig')
     @patch('kiwi.volume_manager.btrfs.DataSync')
     @patch('kiwi.volume_manager.btrfs.Command.run')
@@ -644,19 +579,20 @@ class TestVolumeManagerBtrfs:
         self.volume_manager.set_property_readonly_root()
         mock_command.assert_called_once_with(
             [
-                'btrfs', 'property', 'set', 'tmpdir', 'ro', 'true'
+                'btrfs', 'property',
+                'set', 'tmpdir/@/.snapshots/1/snapshot', 'ro', 'true'
             ]
         )
 
     @patch('kiwi.volume_manager.btrfs.VolumeManagerBtrfs.umount_volumes')
-    def test_destructor(self, mock_umount_volumes):
-        mock_umount_volumes.return_value = True
-        self.volume_manager.toplevel_mount = Mock()
-        with self._caplog.at_level(logging.INFO):
-            self.volume_manager.__del__()
-            mock_umount_volumes.assert_called_once_with()
-        mock_umount_volumes.reset_mock()
-        mock_umount_volumes.return_value = False
-        with self._caplog.at_level(logging.WARNING):
-            self.volume_manager.__del__()
-            mock_umount_volumes.assert_called_once_with()
+    @patch('os.path.exists')
+    def test_context_manager_exit(
+        self, mock_os_path_exists, mock_VolumeManagerBtrfs_umount_volumes
+    ):
+        mock_os_path_exists.return_value = True
+        with VolumeManagerBtrfs(
+            self.device_map, 'root_dir', self.volumes
+        ) as volume_manager:
+            volume_manager.toplevel_mount = Mock()
+
+        mock_VolumeManagerBtrfs_umount_volumes.assert_called_once_with()
