@@ -2,7 +2,7 @@ import os
 import io
 import logging
 from collections import namedtuple
-from mock import (
+from unittest.mock import (
     patch, Mock, MagicMock
 )
 from pytest import (
@@ -58,6 +58,7 @@ class TestXMLState:
         self.bootloader.get_timeout.return_value = 'some-timeout'
         self.bootloader.get_timeout_style.return_value = 'some-style'
         self.bootloader.get_targettype.return_value = 'some-target'
+        self.bootloader.get_bls.return_value = False
         self.bootloader.get_console.return_value = 'some-console'
         self.bootloader.get_serial_line.return_value = 'some-serial'
         self.bootloader.get_use_disk_password.return_value = True
@@ -197,6 +198,11 @@ class TestXMLState:
             'baz'
         ]
 
+    def test_get_bootstrap_ignore_packages(self):
+        assert self.state.get_bootstrap_ignore_packages() == [
+            'some'
+        ]
+
     def test_get_system_collection_type(self):
         assert self.state.get_system_collection_type() == 'plusRecommended'
 
@@ -906,6 +912,7 @@ class TestXMLState:
             'volumes': ['/tmp', '/var/log'],
             'entry_command': ['/bin/bash', '-x'],
             'expose_ports': ['80', '8080'],
+            'stopsignal': 'SIGINT',
             'history': {
                 'author': 'history author',
                 'comment': 'This is a comment',
@@ -1032,6 +1039,11 @@ class TestXMLState:
         mock_bootloader.return_value = [self.bootloader]
         assert self.state.get_build_type_bootloader_use_disk_password() is True
 
+    @patch('kiwi.xml_parse.type_.get_bootloader')
+    def test_get_build_type_bootloader_bls(self, mock_bootloader):
+        mock_bootloader.return_value = [self.bootloader]
+        assert self.state.get_build_type_bootloader_bls() is False
+
     @patch('kiwi.xml_parse.type_.get_bootloader')
     def test_get_build_type_bootloader_console(self, mock_bootloader):
         mock_bootloader.return_value = [self.bootloader]
